/* GDocumentTest.c generated by valac 0.34.6, the Vala compiler
 * generated from GDocumentTest.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: t; c-basic-offset: 2; tab-width: 2 -*- */
/* Notation.vala
 *
 * Copyright (C) 2011-2013  Richard Schwarting <aquarichy@gmail.com>
 * Copyright (C) 2011-2015  Daniel Espinosa <esodan@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *      Richard Schwarting <aquarichy@gmail.com>
 *      Daniel Espinosa <esodan@gmail.com>
 */

#include <glib.h>
#include <glib-object.h>
#include <gxml/gxml.h>
#include <gee.h>
#include <gio/gio.h>
#include <stdlib.h>
#include <string.h>


#define TYPE_GXML_TEST (gxml_test_get_type ())
#define GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GXML_TEST, GXmlTest))
#define GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GXML_TEST, GXmlTestClass))
#define IS_GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GXML_TEST))
#define IS_GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GXML_TEST))
#define GXML_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GXML_TEST, GXmlTestClass))

typedef struct _GXmlTest GXmlTest;
typedef struct _GXmlTestClass GXmlTestClass;
typedef struct _GXmlTestPrivate GXmlTestPrivate;

#define TYPE_GDOCUMENT_TEST (gdocument_test_get_type ())
#define GDOCUMENT_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GDOCUMENT_TEST, GDocumentTest))
#define GDOCUMENT_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GDOCUMENT_TEST, GDocumentTestClass))
#define IS_GDOCUMENT_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GDOCUMENT_TEST))
#define IS_GDOCUMENT_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GDOCUMENT_TEST))
#define GDOCUMENT_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GDOCUMENT_TEST, GDocumentTestClass))

typedef struct _GDocumentTest GDocumentTest;
typedef struct _GDocumentTestClass GDocumentTestClass;
typedef struct _GDocumentTestPrivate GDocumentTestPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _g_string_free0(var) ((var == NULL) ? NULL : (var = (g_string_free (var, TRUE), NULL)))
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _GXmlTest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GXmlTestPrivate * priv;
};

struct _GXmlTestClass {
	GTypeClass parent_class;
	void (*finalize) (GXmlTest *self);
};

struct _GDocumentTest {
	GXmlTest parent_instance;
	GDocumentTestPrivate * priv;
};

struct _GDocumentTestClass {
	GXmlTestClass parent_class;
};


static gpointer gdocument_test_parent_class = NULL;

gpointer gxml_test_ref (gpointer instance);
void gxml_test_unref (gpointer instance);
GParamSpec* param_spec_gxml_test (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_gxml_test (GValue* value, gpointer v_object);
void value_take_gxml_test (GValue* value, gpointer v_object);
gpointer value_get_gxml_test (const GValue* value);
GType gxml_test_get_type (void) G_GNUC_CONST;
GType gdocument_test_get_type (void) G_GNUC_CONST;
enum  {
	GDOCUMENT_TEST_DUMMY_PROPERTY
};
void gdocument_test_add_tests (void);
static void __lambda158_ (void);
static void ___lambda158__gtest_func (void);
static void __lambda159_ (void);
static void ___lambda159__gtest_func (void);
static void __lambda160_ (void);
static void ___lambda160__gtest_func (void);
static void __lambda161_ (void);
static void ___lambda161__gtest_func (void);
static void __lambda162_ (void);
static void ___lambda162__gtest_func (void);
static void __lambda163_ (void);
static void ___lambda163__gtest_func (void);
static void __lambda164_ (void);
static void ___lambda164__gtest_func (void);
static void __lambda165_ (void);
static void ___lambda165__gtest_func (void);
static void __lambda166_ (void);
static void ___lambda166__gtest_func (void);
static void __lambda167_ (void);
static void ___lambda167__gtest_func (void);
static void __lambda168_ (void);
static void ___lambda168__gtest_func (void);
static void __lambda169_ (void);
static void ___lambda169__gtest_func (void);
static void __lambda170_ (void);
static void ___lambda170__gtest_func (void);
static void __lambda171_ (void);
static void ___lambda171__gtest_func (void);
static void __lambda172_ (void);
static void ___lambda172__gtest_func (void);
static void __lambda173_ (void);
static void ___lambda173__gtest_func (void);
static void __lambda174_ (void);
static void ___lambda174__gtest_func (void);
static void __lambda175_ (void);
static void ___lambda175__gtest_func (void);
static void __lambda176_ (void);
static void ___lambda176__gtest_func (void);
static void __lambda177_ (void);
static void ___lambda177__gtest_func (void);
static void __lambda178_ (void);
static void ___lambda178__gtest_func (void);
static void __lambda179_ (void);
static void ___lambda179__gtest_func (void);
GDocumentTest* gdocument_test_new (void);
GDocumentTest* gdocument_test_construct (GType object_type);
GXmlTest* gxml_test_new (void);
GXmlTest* gxml_test_construct (GType object_type);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
static gint _vala_array_length (gpointer array);


static void __lambda158_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGDocument* d = NULL;
		GXmlGDocument* _tmp0_ = NULL;
		GXmlNode* root = NULL;
		GXmlNode* _tmp1_ = NULL;
		GeeBidirList* _tmp2_ = NULL;
		GeeBidirList* _tmp3_ = NULL;
		GeeBidirList* _tmp4_ = NULL;
		GXmlNode* _tmp5_ = NULL;
		GXmlNode* _tmp6_ = NULL;
		GXmlNode* _tmp7_ = NULL;
		GXmlNode* _tmp8_ = NULL;
		GXmlNode* _tmp9_ = NULL;
		GXmlNode* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
		gchar* _tmp12_ = NULL;
		gchar* _tmp13_ = NULL;
		gchar* _tmp14_ = NULL;
		gchar* _tmp15_ = NULL;
		GXmlNode* _tmp16_ = NULL;
		GXmlNode* _tmp17_ = NULL;
		GXmlNode* _tmp18_ = NULL;
		gchar* _tmp19_ = NULL;
		gchar* _tmp20_ = NULL;
		gchar* _tmp21_ = NULL;
		GXmlNode* _tmp22_ = NULL;
		GXmlNode* _tmp23_ = NULL;
		GXmlNode* _tmp24_ = NULL;
		gchar* _tmp25_ = NULL;
		gchar* _tmp26_ = NULL;
		gchar* _tmp27_ = NULL;
		gchar* _tmp28_ = NULL;
		GXmlNode* _tmp29_ = NULL;
		GXmlNode* _tmp30_ = NULL;
		GXmlNode* _tmp31_ = NULL;
		gchar* _tmp32_ = NULL;
		gchar* _tmp33_ = NULL;
#line 31 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp0_ = gxml_gdocument_new ();
#line 31 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		d = _tmp0_;
#line 32 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp1_ = gxml_document_create_element ((GXmlDocument*) d, "root", &_inner_error_);
#line 32 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		root = _tmp1_;
#line 32 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 32 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_g_object_unref0 (d);
#line 207 "GDocumentTest.c"
			goto __catch143_g_error;
		}
#line 33 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp2_ = gxml_gnode_get_children_nodes ((GXmlGNode*) d);
#line 33 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp3_ = _tmp2_;
#line 33 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp4_ = _tmp3_;
#line 33 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		gee_collection_add ((GeeCollection*) _tmp4_, root);
#line 33 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp4_);
#line 34 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp5_ = gxml_document_get_root ((GXmlDocument*) d);
#line 34 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 34 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 34 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (_tmp7_ != NULL, "d.root != null");
#line 34 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp7_);
#line 35 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp8_ = gxml_document_get_root ((GXmlDocument*) d);
#line 35 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 35 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp10_ = _tmp9_;
#line 35 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp11_ = gxml_node_get_name (_tmp10_);
#line 35 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp12_ = _tmp11_;
#line 35 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp13_ = _tmp12_;
#line 35 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp14_ = g_strconcat ("Root name: ", _tmp13_, NULL);
#line 35 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp15_ = _tmp14_;
#line 35 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_test_message ("%s", _tmp15_);
#line 35 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp15_);
#line 35 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp13_);
#line 35 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp10_);
#line 36 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp16_ = gxml_document_get_root ((GXmlDocument*) d);
#line 36 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp17_ = _tmp16_;
#line 36 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp18_ = _tmp17_;
#line 36 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp19_ = gxml_node_get_name (_tmp18_);
#line 36 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp20_ = _tmp19_;
#line 36 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp21_ = _tmp20_;
#line 36 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp21_, "root") == 0, "d.root.name == \"root\"");
#line 36 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp21_);
#line 36 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp18_);
#line 37 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp22_ = gxml_document_get_root ((GXmlDocument*) d);
#line 37 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 37 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp24_ = _tmp23_;
#line 37 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp25_ = gxml_node_to_string (_tmp24_);
#line 37 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp26_ = _tmp25_;
#line 37 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp27_ = g_strconcat ("Root string: ", _tmp26_, NULL);
#line 37 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp28_ = _tmp27_;
#line 37 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_test_message ("%s", _tmp28_);
#line 37 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp28_);
#line 37 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp26_);
#line 37 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp24_);
#line 38 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp29_ = gxml_document_get_root ((GXmlDocument*) d);
#line 38 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp30_ = _tmp29_;
#line 38 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp31_ = _tmp30_;
#line 38 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp32_ = gxml_node_to_string (_tmp31_);
#line 38 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp33_ = _tmp32_;
#line 38 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp33_, "<root/>") == 0, "d.root.to_string () == \"<root/>\"");
#line 38 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp33_);
#line 38 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp31_);
#line 30 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (root);
#line 30 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (d);
#line 314 "GDocumentTest.c"
	}
	goto __finally143;
	__catch143_g_error:
	{
#line 30 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 30 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_inner_error_ = NULL;
#line 39 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_assert_not_reached ();
#line 325 "GDocumentTest.c"
	}
	__finally143:
#line 30 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 30 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 30 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 30 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		return;
#line 336 "GDocumentTest.c"
	}
}


static void ___lambda158__gtest_func (void) {
#line 29 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	__lambda158_ ();
#line 344 "GDocumentTest.c"
}


static void __lambda159_ (void) {
	GXmlGDocument* doc = NULL;
	GError * _inner_error_ = NULL;
	{
		GXmlGDocument* _tmp0_ = NULL;
		GXmlGDocument* _tmp1_ = NULL;
		GXmlGDocument* _tmp2_ = NULL;
#line 44 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_test_message ("invalid file...");
#line 46 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp1_ = gxml_gdocument_new_from_path ("/tmp/asdfjlkansdlfjl", 0, &_inner_error_);
#line 46 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp0_ = _tmp1_;
#line 46 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 363 "GDocumentTest.c"
			goto __catch144_g_error;
		}
#line 46 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp2_ = _tmp0_;
#line 46 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp0_ = NULL;
#line 46 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 46 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		doc = _tmp2_;
#line 47 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_assert_not_reached ();
#line 43 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp0_);
#line 378 "GDocumentTest.c"
	}
	goto __finally144;
	__catch144_g_error:
	{
#line 43 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 43 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_inner_error_ = NULL;
#line 387 "GDocumentTest.c"
	}
	__finally144:
#line 43 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 43 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 43 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 43 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 43 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		return;
#line 400 "GDocumentTest.c"
	}
	{
		GXmlGDocument* _tmp3_ = NULL;
		GXmlGDocument* _tmp4_ = NULL;
		GXmlGDocument* _tmp5_ = NULL;
#line 52 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp4_ = gxml_gdocument_new_from_path ("/tmp/", 0, &_inner_error_);
#line 52 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp3_ = _tmp4_;
#line 52 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 412 "GDocumentTest.c"
			goto __catch145_g_error;
		}
#line 52 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp5_ = _tmp3_;
#line 52 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp3_ = NULL;
#line 52 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 52 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		doc = _tmp5_;
#line 53 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_assert_not_reached ();
#line 50 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp3_);
#line 427 "GDocumentTest.c"
	}
	goto __finally145;
	__catch145_g_error:
	{
#line 50 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 50 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_inner_error_ = NULL;
#line 436 "GDocumentTest.c"
	}
	__finally145:
#line 50 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 50 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 50 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 50 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 50 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		return;
#line 449 "GDocumentTest.c"
	}
	{
		GXmlGDocument* _tmp6_ = NULL;
		GXmlGDocument* _tmp7_ = NULL;
		GXmlGDocument* _tmp8_ = NULL;
#line 56 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp7_ = gxml_gdocument_new_from_path ("test_invalid.xml", 0, &_inner_error_);
#line 56 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp6_ = _tmp7_;
#line 56 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 461 "GDocumentTest.c"
			goto __catch146_g_error;
		}
#line 56 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp8_ = _tmp6_;
#line 56 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp6_ = NULL;
#line 56 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 56 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		doc = _tmp8_;
#line 57 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_assert_not_reached ();
#line 55 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp6_);
#line 476 "GDocumentTest.c"
	}
	goto __finally146;
	__catch146_g_error:
	{
#line 55 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 55 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_inner_error_ = NULL;
#line 485 "GDocumentTest.c"
	}
	__finally146:
#line 55 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 55 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 55 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 55 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 55 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		return;
#line 498 "GDocumentTest.c"
	}
#line 41 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	_g_object_unref0 (doc);
#line 502 "GDocumentTest.c"
}


static void ___lambda159__gtest_func (void) {
#line 41 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	__lambda159_ ();
#line 509 "GDocumentTest.c"
}


static void __lambda160_ (void) {
	GFile* fin = NULL;
	GFile* _tmp0_ = NULL;
	GFile* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	GError * _inner_error_ = NULL;
#line 61 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	_tmp0_ = g_file_new_for_path (TEST_DIR "/test.xml");
#line 61 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	fin = _tmp0_;
#line 62 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	_tmp1_ = fin;
#line 62 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	_tmp2_ = g_file_query_exists (_tmp1_, NULL);
#line 62 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	_vala_assert (_tmp2_, "fin.query_exists ()");
#line 529 "GDocumentTest.c"
	{
		GFileInputStream* instream = NULL;
		GFile* _tmp3_ = NULL;
		GFileInputStream* _tmp4_ = NULL;
		GXmlGDocument* doc = NULL;
		GFileInputStream* _tmp5_ = NULL;
		GXmlGDocument* _tmp6_ = NULL;
		GXmlGDocument* _tmp7_ = NULL;
#line 64 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp3_ = fin;
#line 64 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp4_ = g_file_read (_tmp3_, NULL, &_inner_error_);
#line 64 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		instream = _tmp4_;
#line 64 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 546 "GDocumentTest.c"
			goto __catch147_g_error;
		}
#line 65 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp5_ = instream;
#line 65 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp6_ = gxml_gdocument_new_from_stream ((GInputStream*) _tmp5_, &_inner_error_);
#line 65 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		doc = _tmp6_;
#line 65 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 65 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_g_object_unref0 (instream);
#line 559 "GDocumentTest.c"
			goto __catch147_g_error;
		}
#line 66 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp7_ = doc;
#line 66 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (_tmp7_ != NULL, "doc != null");
#line 63 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 63 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (instream);
#line 570 "GDocumentTest.c"
	}
	goto __finally147;
	__catch147_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp8_ = NULL;
#line 63 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		e = _inner_error_;
#line 63 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_inner_error_ = NULL;
#line 69 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp8_ = e->message;
#line 69 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_message ("GDocumentTest.vala:69: %s", _tmp8_);
#line 70 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_assert_not_reached ();
#line 63 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_error_free0 (e);
#line 589 "GDocumentTest.c"
	}
	__finally147:
#line 63 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 63 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (fin);
#line 63 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 63 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 63 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		return;
#line 602 "GDocumentTest.c"
	}
#line 60 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	_g_object_unref0 (fin);
#line 606 "GDocumentTest.c"
}


static void ___lambda160__gtest_func (void) {
#line 60 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	__lambda160_ ();
#line 613 "GDocumentTest.c"
}


static void __lambda161_ (void) {
	GError * _inner_error_ = NULL;
	{
		GFile* f = NULL;
		GFile* _tmp0_ = NULL;
		GFile* _tmp1_ = NULL;
		gboolean _tmp2_ = FALSE;
		GString* s = NULL;
		GString* _tmp4_ = NULL;
		GString* _tmp5_ = NULL;
		GXmlGDocument* d = NULL;
		GString* _tmp6_ = NULL;
		const gchar* _tmp7_ = NULL;
		GXmlGDocument* _tmp8_ = NULL;
		GFile* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
		gchar* _tmp12_ = NULL;
		gchar* _tmp13_ = NULL;
		GXmlGDocument* _tmp14_ = NULL;
		gchar* _tmp15_ = NULL;
		gchar* _tmp16_ = NULL;
		gchar* _tmp17_ = NULL;
		gchar* _tmp18_ = NULL;
		GXmlGDocument* _tmp19_ = NULL;
		GFile* _tmp20_ = NULL;
		GFile* _tmp21_ = NULL;
		gboolean _tmp22_ = FALSE;
		GXmlGDocument* d2 = NULL;
		GFile* _tmp23_ = NULL;
		GXmlGDocument* _tmp24_ = NULL;
		GXmlGDocument* _tmp25_ = NULL;
		GXmlGDocument* _tmp26_ = NULL;
		GXmlNode* _tmp27_ = NULL;
		GXmlNode* _tmp28_ = NULL;
		GXmlNode* _tmp29_ = NULL;
		GXmlGDocument* _tmp30_ = NULL;
		GXmlNode* _tmp31_ = NULL;
		GXmlNode* _tmp32_ = NULL;
		GXmlNode* _tmp33_ = NULL;
		gchar* _tmp34_ = NULL;
		gchar* _tmp35_ = NULL;
		gchar* _tmp36_ = NULL;
		GFile* _tmp37_ = NULL;
#line 75 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp0_ = g_file_new_for_path (TEST_SAVE_DIR "/tw-test-file.xml");
#line 75 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		f = _tmp0_;
#line 76 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp1_ = f;
#line 76 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp2_ = g_file_query_exists (_tmp1_, NULL);
#line 76 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		if (_tmp2_) {
#line 671 "GDocumentTest.c"
			GFile* _tmp3_ = NULL;
#line 76 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_tmp3_ = f;
#line 76 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			g_file_delete (_tmp3_, NULL, &_inner_error_);
#line 76 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 76 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
				_g_object_unref0 (f);
#line 681 "GDocumentTest.c"
				goto __catch148_g_error;
			}
		}
#line 77 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp4_ = g_string_new ("");
#line 77 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		s = _tmp4_;
#line 78 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp5_ = s;
#line 78 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_string_append (_tmp5_, "<root />");
#line 79 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp6_ = s;
#line 79 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp7_ = _tmp6_->str;
#line 79 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp8_ = gxml_gdocument_new_from_string (_tmp7_, 0, &_inner_error_);
#line 79 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		d = _tmp8_;
#line 79 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 79 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_g_string_free0 (s);
#line 79 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_g_object_unref0 (f);
#line 707 "GDocumentTest.c"
			goto __catch148_g_error;
		}
#line 80 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp9_ = f;
#line 80 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp10_ = g_file_get_uri (_tmp9_);
#line 80 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp11_ = _tmp10_;
#line 80 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp12_ = g_strconcat ("Saving to file: ", _tmp11_, NULL);
#line 80 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp13_ = _tmp12_;
#line 80 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp14_ = d;
#line 80 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp15_ = gxml_gnode_to_string ((GXmlGNode*) _tmp14_);
#line 80 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp16_ = _tmp15_;
#line 80 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp17_ = g_strconcat (_tmp13_, _tmp16_, NULL);
#line 80 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp18_ = _tmp17_;
#line 80 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_test_message ("%s", _tmp18_);
#line 80 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp18_);
#line 80 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp16_);
#line 80 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp13_);
#line 80 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp11_);
#line 81 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp19_ = d;
#line 81 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp20_ = f;
#line 81 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		gxml_gdocument_save_as (_tmp19_, _tmp20_, NULL, &_inner_error_);
#line 81 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 81 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_g_object_unref0 (d);
#line 81 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_g_string_free0 (s);
#line 81 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_g_object_unref0 (f);
#line 754 "GDocumentTest.c"
			goto __catch148_g_error;
		}
#line 82 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp21_ = f;
#line 82 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp22_ = g_file_query_exists (_tmp21_, NULL);
#line 82 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (_tmp22_, "f.query_exists ()");
#line 83 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp23_ = f;
#line 83 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp24_ = gxml_gdocument_new_from_file (_tmp23_, 0, NULL, &_inner_error_);
#line 83 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		d2 = _tmp24_;
#line 83 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 83 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_g_object_unref0 (d);
#line 83 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_g_string_free0 (s);
#line 83 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_g_object_unref0 (f);
#line 777 "GDocumentTest.c"
			goto __catch148_g_error;
		}
#line 84 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp25_ = d2;
#line 84 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (_tmp25_ != NULL, "d2 != null");
#line 85 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp26_ = d2;
#line 85 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp27_ = gxml_document_get_root ((GXmlDocument*) _tmp26_);
#line 85 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp28_ = _tmp27_;
#line 85 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp29_ = _tmp28_;
#line 85 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (_tmp29_ != NULL, "d2.root != null");
#line 85 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp29_);
#line 86 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp30_ = d2;
#line 86 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp31_ = gxml_document_get_root ((GXmlDocument*) _tmp30_);
#line 86 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp32_ = _tmp31_;
#line 86 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp33_ = _tmp32_;
#line 86 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp34_ = gxml_node_get_name (_tmp33_);
#line 86 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp35_ = _tmp34_;
#line 86 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp36_ = _tmp35_;
#line 86 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp36_, "root") == 0, "d2.root.name == \"root\"");
#line 86 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp36_);
#line 86 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp33_);
#line 87 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp37_ = f;
#line 87 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_file_delete (_tmp37_, NULL, &_inner_error_);
#line 87 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 87 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_g_object_unref0 (d2);
#line 87 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_g_object_unref0 (d);
#line 87 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_g_string_free0 (s);
#line 87 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_g_object_unref0 (f);
#line 830 "GDocumentTest.c"
			goto __catch148_g_error;
		}
#line 74 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (d2);
#line 74 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (d);
#line 74 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_string_free0 (s);
#line 74 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (f);
#line 841 "GDocumentTest.c"
	}
	goto __finally148;
	__catch148_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp38_ = NULL;
		gchar* _tmp39_ = NULL;
		gchar* _tmp40_ = NULL;
#line 74 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		e = _inner_error_;
#line 74 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_inner_error_ = NULL;
#line 89 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp38_ = e->message;
#line 89 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp39_ = g_strconcat ("Error: ", _tmp38_, NULL);
#line 89 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp40_ = _tmp39_;
#line 89 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_message ("GDocumentTest.vala:89: %s", _tmp40_);
#line 89 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp40_);
#line 90 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_assert_not_reached ();
#line 74 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_error_free0 (e);
#line 868 "GDocumentTest.c"
	}
	__finally148:
#line 74 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 74 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 74 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 74 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		return;
#line 879 "GDocumentTest.c"
	}
}


static void ___lambda161__gtest_func (void) {
#line 73 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	__lambda161_ ();
#line 887 "GDocumentTest.c"
}


static void __lambda162_ (void) {
	GError * _inner_error_ = NULL;
	{
		GFile* rf = NULL;
		GFile* _tmp0_ = NULL;
		GFile* _tmp1_ = NULL;
		gboolean _tmp2_ = FALSE;
		GXmlGDocument* d = NULL;
		GFile* _tmp3_ = NULL;
		GXmlGDocument* _tmp4_ = NULL;
		GXmlGDocument* _tmp5_ = NULL;
		GXmlGDocument* _tmp6_ = NULL;
		GXmlNode* _tmp7_ = NULL;
		GXmlNode* _tmp8_ = NULL;
		GXmlNode* _tmp9_ = NULL;
		GXmlGDocument* _tmp10_ = NULL;
		GXmlNode* _tmp11_ = NULL;
		GXmlNode* _tmp12_ = NULL;
		GXmlNode* _tmp13_ = NULL;
		gchar* _tmp14_ = NULL;
		gchar* _tmp15_ = NULL;
		gchar* _tmp16_ = NULL;
		gboolean fname = FALSE;
		gboolean fshordesc = FALSE;
		gboolean fdescription = FALSE;
		gboolean fhomepage = FALSE;
		gboolean _tmp17_ = FALSE;
		gboolean _tmp18_ = FALSE;
		gboolean _tmp19_ = FALSE;
		gboolean _tmp56_ = FALSE;
		gboolean _tmp57_ = FALSE;
		gboolean _tmp58_ = FALSE;
		gboolean _tmp59_ = FALSE;
		GFile* f = NULL;
		GFile* _tmp60_ = NULL;
		GXmlGDocument* _tmp61_ = NULL;
		GFile* _tmp62_ = NULL;
		GFile* _tmp63_ = NULL;
		gboolean _tmp64_ = FALSE;
		GFile* _tmp65_ = NULL;
#line 95 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp0_ = g_file_new_for_uri ("https://git.gnome.org/browse/gxml/plain/gxml.doap");
#line 95 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		rf = _tmp0_;
#line 96 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp1_ = rf;
#line 96 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp2_ = g_file_query_exists (_tmp1_, NULL);
#line 96 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		if (!_tmp2_) {
#line 97 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			g_message ("GDocumentTest.vala:97: No remote file available. Skiping...");
#line 98 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_g_object_unref0 (rf);
#line 98 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			return;
#line 947 "GDocumentTest.c"
		}
#line 100 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp3_ = rf;
#line 100 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp4_ = gxml_gdocument_new_from_file (_tmp3_, 0, NULL, &_inner_error_);
#line 100 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		d = _tmp4_;
#line 100 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 100 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_g_object_unref0 (rf);
#line 959 "GDocumentTest.c"
			goto __catch149_g_error;
		}
#line 101 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp5_ = d;
#line 101 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (_tmp5_ != NULL, "d != null");
#line 102 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp6_ = d;
#line 102 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp7_ = gxml_document_get_root ((GXmlDocument*) _tmp6_);
#line 102 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp8_ = _tmp7_;
#line 102 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 102 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (_tmp9_ != NULL, "d.root != null");
#line 102 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp9_);
#line 103 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp10_ = d;
#line 103 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp11_ = gxml_document_get_root ((GXmlDocument*) _tmp10_);
#line 103 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp12_ = _tmp11_;
#line 103 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp13_ = _tmp12_;
#line 103 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp14_ = gxml_node_get_name (_tmp13_);
#line 103 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp15_ = _tmp14_;
#line 103 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp16_ = _tmp15_;
#line 103 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp16_, "Project") == 0, "d.root.name == \"Project\"");
#line 103 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp16_);
#line 103 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp13_);
#line 105 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		fhomepage = FALSE;
#line 105 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp17_ = fhomepage;
#line 105 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		fdescription = _tmp17_;
#line 105 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp18_ = fdescription;
#line 105 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		fshordesc = _tmp18_;
#line 105 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp19_ = fshordesc;
#line 105 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		fname = _tmp19_;
#line 1012 "GDocumentTest.c"
		{
			GeeBidirList* _n_list = NULL;
			GXmlGDocument* _tmp20_ = NULL;
			GXmlNode* _tmp21_ = NULL;
			GXmlNode* _tmp22_ = NULL;
			GXmlNode* _tmp23_ = NULL;
			GeeBidirList* _tmp24_ = NULL;
			GeeBidirList* _tmp25_ = NULL;
			GeeBidirList* _tmp26_ = NULL;
			gint _n_size = 0;
			GeeBidirList* _tmp27_ = NULL;
			gint _tmp28_ = 0;
			gint _tmp29_ = 0;
			gint _n_index = 0;
#line 106 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_tmp20_ = d;
#line 106 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_tmp21_ = gxml_document_get_root ((GXmlDocument*) _tmp20_);
#line 106 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_tmp22_ = _tmp21_;
#line 106 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_tmp23_ = _tmp22_;
#line 106 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_tmp24_ = gxml_node_get_children_nodes (_tmp23_);
#line 106 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_tmp25_ = _tmp24_;
#line 106 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_tmp26_ = _tmp25_;
#line 106 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_g_object_unref0 (_tmp23_);
#line 106 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_n_list = _tmp26_;
#line 106 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_tmp27_ = _n_list;
#line 106 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_tmp28_ = gee_collection_get_size ((GeeCollection*) _tmp27_);
#line 106 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_tmp29_ = _tmp28_;
#line 106 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_n_size = _tmp29_;
#line 106 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_n_index = -1;
#line 106 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			while (TRUE) {
#line 1057 "GDocumentTest.c"
				gint _tmp30_ = 0;
				gint _tmp31_ = 0;
				gint _tmp32_ = 0;
				GXmlNode* n = NULL;
				GeeBidirList* _tmp33_ = NULL;
				gint _tmp34_ = 0;
				gpointer _tmp35_ = NULL;
				GXmlNode* _tmp36_ = NULL;
				gchar* _tmp37_ = NULL;
				gchar* _tmp38_ = NULL;
				gchar* _tmp39_ = NULL;
				gboolean _tmp40_ = FALSE;
				GXmlNode* _tmp41_ = NULL;
				gchar* _tmp42_ = NULL;
				gchar* _tmp43_ = NULL;
				gchar* _tmp44_ = NULL;
				gboolean _tmp45_ = FALSE;
				GXmlNode* _tmp46_ = NULL;
				gchar* _tmp47_ = NULL;
				gchar* _tmp48_ = NULL;
				gchar* _tmp49_ = NULL;
				gboolean _tmp50_ = FALSE;
				GXmlNode* _tmp51_ = NULL;
				gchar* _tmp52_ = NULL;
				gchar* _tmp53_ = NULL;
				gchar* _tmp54_ = NULL;
				gboolean _tmp55_ = FALSE;
#line 106 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
				_tmp30_ = _n_index;
#line 106 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
				_n_index = _tmp30_ + 1;
#line 106 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
				_tmp31_ = _n_index;
#line 106 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
				_tmp32_ = _n_size;
#line 106 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
				if (!(_tmp31_ < _tmp32_)) {
#line 106 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
					break;
#line 1097 "GDocumentTest.c"
				}
#line 106 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
				_tmp33_ = _n_list;
#line 106 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
				_tmp34_ = _n_index;
#line 106 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
				_tmp35_ = gee_list_get ((GeeList*) _tmp33_, _tmp34_);
#line 106 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
				n = (GXmlNode*) _tmp35_;
#line 107 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
				_tmp36_ = n;
#line 107 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
				_tmp37_ = gxml_node_get_name (_tmp36_);
#line 107 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
				_tmp38_ = _tmp37_;
#line 107 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
				_tmp39_ = _tmp38_;
#line 107 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
				_tmp40_ = g_strcmp0 (_tmp39_, "name") == 0;
#line 107 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
				_g_free0 (_tmp39_);
#line 107 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
				if (_tmp40_) {
#line 107 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
					fname = TRUE;
#line 1123 "GDocumentTest.c"
				}
#line 108 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
				_tmp41_ = n;
#line 108 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
				_tmp42_ = gxml_node_get_name (_tmp41_);
#line 108 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
				_tmp43_ = _tmp42_;
#line 108 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
				_tmp44_ = _tmp43_;
#line 108 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
				_tmp45_ = g_strcmp0 (_tmp44_, "shortdesc") == 0;
#line 108 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
				_g_free0 (_tmp44_);
#line 108 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
				if (_tmp45_) {
#line 108 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
					fshordesc = TRUE;
#line 1141 "GDocumentTest.c"
				}
#line 109 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
				_tmp46_ = n;
#line 109 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
				_tmp47_ = gxml_node_get_name (_tmp46_);
#line 109 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
				_tmp48_ = _tmp47_;
#line 109 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
				_tmp49_ = _tmp48_;
#line 109 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
				_tmp50_ = g_strcmp0 (_tmp49_, "description") == 0;
#line 109 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
				_g_free0 (_tmp49_);
#line 109 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
				if (_tmp50_) {
#line 109 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
					fdescription = TRUE;
#line 1159 "GDocumentTest.c"
				}
#line 110 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
				_tmp51_ = n;
#line 110 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
				_tmp52_ = gxml_node_get_name (_tmp51_);
#line 110 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
				_tmp53_ = _tmp52_;
#line 110 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
				_tmp54_ = _tmp53_;
#line 110 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
				_tmp55_ = g_strcmp0 (_tmp54_, "homepage") == 0;
#line 110 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
				_g_free0 (_tmp54_);
#line 110 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
				if (_tmp55_) {
#line 110 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
					fhomepage = TRUE;
#line 1177 "GDocumentTest.c"
				}
#line 106 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
				_g_object_unref0 (n);
#line 1181 "GDocumentTest.c"
			}
#line 106 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_g_object_unref0 (_n_list);
#line 1185 "GDocumentTest.c"
		}
#line 112 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp56_ = fname;
#line 112 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (_tmp56_, "fname");
#line 113 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp57_ = fshordesc;
#line 113 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (_tmp57_, "fshordesc");
#line 114 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp58_ = fdescription;
#line 114 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (_tmp58_, "fdescription");
#line 115 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp59_ = fhomepage;
#line 115 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (_tmp59_, "fhomepage");
#line 116 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp60_ = g_file_new_for_path (TEST_SAVE_DIR "/xml.doap");
#line 116 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		f = _tmp60_;
#line 117 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp61_ = d;
#line 117 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp62_ = f;
#line 117 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		gxml_gdocument_save_as (_tmp61_, _tmp62_, NULL, &_inner_error_);
#line 117 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 117 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_g_object_unref0 (f);
#line 117 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_g_object_unref0 (d);
#line 117 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_g_object_unref0 (rf);
#line 1221 "GDocumentTest.c"
			goto __catch149_g_error;
		}
#line 118 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp63_ = f;
#line 118 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp64_ = g_file_query_exists (_tmp63_, NULL);
#line 118 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (_tmp64_, "f.query_exists ()");
#line 119 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp65_ = f;
#line 119 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_file_delete (_tmp65_, NULL, &_inner_error_);
#line 119 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 119 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_g_object_unref0 (f);
#line 119 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_g_object_unref0 (d);
#line 119 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_g_object_unref0 (rf);
#line 1242 "GDocumentTest.c"
			goto __catch149_g_error;
		}
#line 94 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (f);
#line 94 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (d);
#line 94 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (rf);
#line 1251 "GDocumentTest.c"
	}
	goto __finally149;
	__catch149_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp66_ = NULL;
		gchar* _tmp67_ = NULL;
		gchar* _tmp68_ = NULL;
#line 94 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		e = _inner_error_;
#line 94 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_inner_error_ = NULL;
#line 121 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp66_ = e->message;
#line 121 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp67_ = g_strconcat ("Error: ", _tmp66_, NULL);
#line 121 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp68_ = _tmp67_;
#line 121 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_message ("GDocumentTest.vala:121: %s", _tmp68_);
#line 121 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp68_);
#line 122 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_assert_not_reached ();
#line 94 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_error_free0 (e);
#line 1278 "GDocumentTest.c"
	}
	__finally149:
#line 94 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 94 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 94 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 94 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		return;
#line 1289 "GDocumentTest.c"
	}
}


static void ___lambda162__gtest_func (void) {
#line 93 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	__lambda162_ ();
#line 1297 "GDocumentTest.c"
}


static void __lambda163_ (void) {
	GFile* fin = NULL;
	GFileIOStream* iostream = NULL;
	GXmlGDocument* doc = NULL;
	GError * _inner_error_ = NULL;
	{
		GFile* _tmp0_ = NULL;
		GFileIOStream* _tmp1_ = NULL;
		GFile* _tmp2_ = NULL;
		GFile* _tmp3_ = NULL;
		GXmlGDocument* _tmp4_ = NULL;
		GFileIOStream* _tmp5_ = NULL;
		GInputStream* _tmp6_ = NULL;
		GInputStream* _tmp7_ = NULL;
		GXmlGDocument* _tmp8_ = NULL;
		GXmlGDocument* _tmp9_ = NULL;
#line 131 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp2_ = g_file_new_tmp ("gxml.XXXXXX", &_tmp1_, &_inner_error_);
#line 131 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (iostream);
#line 131 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		iostream = _tmp1_;
#line 131 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp0_ = _tmp2_;
#line 131 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1327 "GDocumentTest.c"
			goto __catch150_g_error;
		}
#line 131 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp3_ = _tmp0_;
#line 131 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp0_ = NULL;
#line 131 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (fin);
#line 131 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		fin = _tmp3_;
#line 132 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp5_ = iostream;
#line 132 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp6_ = g_io_stream_get_input_stream ((GIOStream*) _tmp5_);
#line 132 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 132 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp8_ = gxml_gdocument_new_from_stream (_tmp7_, &_inner_error_);
#line 132 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp4_ = _tmp8_;
#line 132 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 132 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 1352 "GDocumentTest.c"
			goto __catch150_g_error;
		}
#line 132 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp9_ = _tmp4_;
#line 132 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp4_ = NULL;
#line 132 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 132 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		doc = _tmp9_;
#line 133 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_message ("GDocumentTest.vala:133: Passed parse error stream");
#line 134 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_assert_not_reached ();
#line 130 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp4_);
#line 130 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp0_);
#line 1371 "GDocumentTest.c"
	}
	goto __finally150;
	__catch150_g_error:
	{
#line 130 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 130 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_inner_error_ = NULL;
#line 1380 "GDocumentTest.c"
	}
	__finally150:
#line 130 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 130 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 130 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (iostream);
#line 130 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (fin);
#line 130 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 130 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 130 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		return;
#line 1397 "GDocumentTest.c"
	}
#line 125 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	_g_object_unref0 (doc);
#line 125 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	_g_object_unref0 (iostream);
#line 125 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	_g_object_unref0 (fin);
#line 1405 "GDocumentTest.c"
}


static void ___lambda163__gtest_func (void) {
#line 125 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	__lambda163_ ();
#line 1412 "GDocumentTest.c"
}


static void __lambda164_ (void) {
	GError * _inner_error_ = NULL;
	{
		gchar* xml = NULL;
		GXmlGDocument* doc = NULL;
		GXmlNode* root = NULL;
		gchar* _tmp0_ = NULL;
		GXmlGDocument* _tmp1_ = NULL;
		GXmlGDocument* _tmp2_ = NULL;
		GXmlGDocument* _tmp3_ = NULL;
		GXmlNode* _tmp4_ = NULL;
		GXmlNode* _tmp5_ = NULL;
		GXmlNode* _tmp6_ = NULL;
		GXmlNode* _tmp7_ = NULL;
		GXmlNode* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
		GeeBidirList* _tmp12_ = NULL;
		GeeBidirList* _tmp13_ = NULL;
		GeeBidirList* _tmp14_ = NULL;
		gint _tmp15_ = 0;
		gint _tmp16_ = 0;
		GXmlNode* n1 = NULL;
		GeeBidirList* _tmp17_ = NULL;
		GeeBidirList* _tmp18_ = NULL;
		GeeBidirList* _tmp19_ = NULL;
		gpointer _tmp20_ = NULL;
		GXmlNode* _tmp21_ = NULL;
		gchar* _tmp22_ = NULL;
		gchar* _tmp23_ = NULL;
		gchar* _tmp24_ = NULL;
#line 143 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp0_ = g_strdup ("<Fruits><Apple></Apple><Orange></Orange></Fruits>");
#line 143 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (xml);
#line 143 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		xml = _tmp0_;
#line 144 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp2_ = gxml_gdocument_new_from_string (xml, 0, &_inner_error_);
#line 144 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp1_ = _tmp2_;
#line 144 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 144 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_g_object_unref0 (root);
#line 144 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_g_object_unref0 (doc);
#line 144 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_g_free0 (xml);
#line 1466 "GDocumentTest.c"
			goto __catch151_g_error;
		}
#line 144 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp3_ = _tmp1_;
#line 144 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp1_ = NULL;
#line 144 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 144 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		doc = _tmp3_;
#line 145 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp4_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 145 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp5_ = _tmp4_;
#line 145 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 145 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (_tmp6_ != NULL, "doc.root != null");
#line 145 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp6_);
#line 146 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp7_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 146 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp8_ = _tmp7_;
#line 146 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (root);
#line 146 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		root = _tmp8_;
#line 147 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp9_ = gxml_node_get_name (root);
#line 147 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp10_ = _tmp9_;
#line 147 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp11_ = _tmp10_;
#line 147 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp11_, "Fruits") == 0, "root.name == \"Fruits\"");
#line 147 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp11_);
#line 148 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp12_ = gxml_node_get_children_nodes (root);
#line 148 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp13_ = _tmp12_;
#line 148 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp14_ = _tmp13_;
#line 148 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp15_ = gee_collection_get_size ((GeeCollection*) _tmp14_);
#line 148 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp16_ = _tmp15_;
#line 148 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (_tmp16_ == 2, "root.children_nodes.size == 2");
#line 148 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp14_);
#line 149 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp17_ = gxml_node_get_children_nodes (root);
#line 149 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp18_ = _tmp17_;
#line 149 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp19_ = _tmp18_;
#line 149 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp20_ = gee_list_get ((GeeList*) _tmp19_, 0);
#line 149 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp21_ = (GXmlNode*) _tmp20_;
#line 149 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp19_);
#line 149 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		n1 = _tmp21_;
#line 150 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (n1 != NULL, "n1 != null");
#line 151 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp22_ = gxml_node_get_name (n1);
#line 151 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 151 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp24_ = _tmp23_;
#line 151 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp24_, "Apple") == 0, "n1.name == \"Apple\"");
#line 151 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp24_);
#line 138 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (n1);
#line 138 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp1_);
#line 138 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (root);
#line 138 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 138 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (xml);
#line 1555 "GDocumentTest.c"
	}
	goto __finally151;
	__catch151_g_error:
	{
#line 138 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 138 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_inner_error_ = NULL;
#line 152 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_assert_not_reached ();
#line 1566 "GDocumentTest.c"
	}
	__finally151:
#line 138 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 138 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 138 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 138 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		return;
#line 1577 "GDocumentTest.c"
	}
}


static void ___lambda164__gtest_func (void) {
#line 137 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	__lambda164_ ();
#line 1585 "GDocumentTest.c"
}


static void __lambda165_ (void) {
	GError * _inner_error_ = NULL;
	{
		gchar* xml = NULL;
		GXmlGDocument* doc = NULL;
		gchar* _tmp0_ = NULL;
		GXmlGDocument* _tmp1_ = NULL;
		GXmlGDocument* _tmp2_ = NULL;
		GXmlGDocument* _tmp3_ = NULL;
#line 159 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp0_ = g_strdup ("<?xml version=\"1.0\"?>");
#line 159 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (xml);
#line 159 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		xml = _tmp0_;
#line 160 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp2_ = gxml_gdocument_new_from_string (xml, 0, &_inner_error_);
#line 160 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp1_ = _tmp2_;
#line 160 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 160 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_g_object_unref0 (doc);
#line 160 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_g_free0 (xml);
#line 1614 "GDocumentTest.c"
			goto __catch152_g_error;
		}
#line 160 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp3_ = _tmp1_;
#line 160 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp1_ = NULL;
#line 160 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 160 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		doc = _tmp3_;
#line 161 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_assert_not_reached ();
#line 155 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp1_);
#line 155 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 155 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (xml);
#line 1633 "GDocumentTest.c"
	}
	goto __finally152;
	__catch152_g_error:
	{
#line 155 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 155 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_inner_error_ = NULL;
#line 1642 "GDocumentTest.c"
	}
	__finally152:
#line 155 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 155 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 155 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 155 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		return;
#line 1653 "GDocumentTest.c"
	}
}


static void ___lambda165__gtest_func (void) {
#line 154 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	__lambda165_ ();
#line 1661 "GDocumentTest.c"
}


static void __lambda166_ (void) {
	GError * _inner_error_ = NULL;
	{
		gchar* xml = NULL;
		GXmlGDocument* doc = NULL;
		gchar* _tmp0_ = NULL;
		GXmlGDocument* _tmp1_ = NULL;
		GXmlGDocument* _tmp2_ = NULL;
		GXmlGDocument* _tmp3_ = NULL;
#line 169 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp0_ = g_strdup ("");
#line 169 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (xml);
#line 169 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		xml = _tmp0_;
#line 170 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp2_ = gxml_gdocument_new_from_string (xml, 0, &_inner_error_);
#line 170 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp1_ = _tmp2_;
#line 170 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 170 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_g_object_unref0 (doc);
#line 170 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_g_free0 (xml);
#line 1690 "GDocumentTest.c"
			goto __catch153_g_error;
		}
#line 170 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp3_ = _tmp1_;
#line 170 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp1_ = NULL;
#line 170 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 170 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		doc = _tmp3_;
#line 165 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp1_);
#line 165 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 165 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (xml);
#line 1707 "GDocumentTest.c"
	}
	goto __finally153;
	__catch153_g_error:
	{
#line 165 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 165 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_inner_error_ = NULL;
#line 171 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_assert_not_reached ();
#line 1718 "GDocumentTest.c"
	}
	__finally153:
#line 165 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 165 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 165 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 165 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		return;
#line 1729 "GDocumentTest.c"
	}
}


static void ___lambda166__gtest_func (void) {
#line 164 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	__lambda166_ ();
#line 1737 "GDocumentTest.c"
}


static void __lambda167_ (void) {
	GXmlGDocument* doc = NULL;
	GError * _inner_error_ = NULL;
	{
		GXmlGDocument* _tmp0_ = NULL;
		GXmlGDocument* _tmp1_ = NULL;
		GXmlGDocument* _tmp2_ = NULL;
		GFile* f = NULL;
		GFile* _tmp3_ = NULL;
		GXmlGDocument* _tmp4_ = NULL;
		GFile* _tmp5_ = NULL;
		GFile* _tmp6_ = NULL;
		gboolean _tmp7_ = FALSE;
		GFile* _tmp8_ = NULL;
#line 177 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp1_ = gxml_gdocument_new_from_string ("<root />", 0, &_inner_error_);
#line 177 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp0_ = _tmp1_;
#line 177 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1761 "GDocumentTest.c"
			goto __catch154_g_error;
		}
#line 177 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp2_ = _tmp0_;
#line 177 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp0_ = NULL;
#line 177 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 177 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		doc = _tmp2_;
#line 178 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp3_ = g_file_new_for_path (TEST_SAVE_DIR "/test_out_path.xml");
#line 178 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		f = _tmp3_;
#line 179 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp4_ = doc;
#line 179 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp5_ = f;
#line 179 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		gxml_gdocument_save_as (_tmp4_, _tmp5_, NULL, &_inner_error_);
#line 179 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 179 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_g_object_unref0 (f);
#line 179 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 1788 "GDocumentTest.c"
			goto __catch154_g_error;
		}
#line 180 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp6_ = f;
#line 180 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp7_ = g_file_query_exists (_tmp6_, NULL);
#line 180 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (_tmp7_, "f.query_exists ()");
#line 181 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp8_ = f;
#line 181 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_file_delete (_tmp8_, NULL, &_inner_error_);
#line 181 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 181 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_g_object_unref0 (f);
#line 181 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 1807 "GDocumentTest.c"
			goto __catch154_g_error;
		}
#line 176 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (f);
#line 176 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp0_);
#line 1814 "GDocumentTest.c"
	}
	goto __finally154;
	__catch154_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp9_ = NULL;
#line 176 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		e = _inner_error_;
#line 176 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_inner_error_ = NULL;
#line 183 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp9_ = e->message;
#line 183 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_test_message ("%s", _tmp9_);
#line 184 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_assert_not_reached ();
#line 176 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_error_free0 (e);
#line 1833 "GDocumentTest.c"
	}
	__finally154:
#line 176 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 176 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 176 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 176 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 176 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		return;
#line 1846 "GDocumentTest.c"
	}
#line 173 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	_g_object_unref0 (doc);
#line 1850 "GDocumentTest.c"
}


static void ___lambda167__gtest_func (void) {
#line 173 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	__lambda167_ ();
#line 1857 "GDocumentTest.c"
}


static void __lambda168_ (void) {
	GXmlGDocument* doc = NULL;
	GError * _inner_error_ = NULL;
	{
		GXmlGDocument* _tmp0_ = NULL;
		GXmlGDocument* _tmp1_ = NULL;
		GXmlGDocument* _tmp2_ = NULL;
		GXmlGDocument* _tmp3_ = NULL;
		GFile* _tmp4_ = NULL;
		GFile* _tmp5_ = NULL;
#line 191 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp1_ = gxml_gdocument_new_from_string ("<root />", 0, &_inner_error_);
#line 191 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp0_ = _tmp1_;
#line 191 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1877 "GDocumentTest.c"
			goto __catch155_g_error;
		}
#line 191 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp2_ = _tmp0_;
#line 191 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp0_ = NULL;
#line 191 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 191 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		doc = _tmp2_;
#line 192 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp3_ = doc;
#line 192 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp4_ = g_file_new_for_path ("/tmp/a/b/c/d/e/f/g/h/i");
#line 192 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp5_ = _tmp4_;
#line 192 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		gxml_gdocument_save_as (_tmp3_, _tmp5_, NULL, &_inner_error_);
#line 192 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp5_);
#line 192 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 192 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 1902 "GDocumentTest.c"
			goto __catch155_g_error;
		}
#line 193 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_assert_not_reached ();
#line 190 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp0_);
#line 1909 "GDocumentTest.c"
	}
	goto __finally155;
	__catch155_g_error:
	{
#line 190 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 190 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_inner_error_ = NULL;
#line 1918 "GDocumentTest.c"
	}
	__finally155:
#line 190 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 190 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 190 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 190 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 190 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		return;
#line 1931 "GDocumentTest.c"
	}
#line 187 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	_g_object_unref0 (doc);
#line 1935 "GDocumentTest.c"
}


static void ___lambda168__gtest_func (void) {
#line 187 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	__lambda168_ ();
#line 1942 "GDocumentTest.c"
}


static void __lambda169_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_ = NULL;
		GXmlGElement* elem = NULL;
		GXmlNode* _tmp1_ = NULL;
		GXmlGDocument* _tmp2_ = NULL;
		GXmlNode* _tmp3_ = NULL;
		GXmlNode* _tmp4_ = NULL;
		GXmlGElement* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		GXmlGElement* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
		gchar* _tmp12_ = NULL;
		GXmlNode* _tmp13_ = NULL;
		GXmlGDocument* _tmp14_ = NULL;
		GXmlNode* _tmp15_ = NULL;
		GXmlNode* _tmp16_ = NULL;
#line 199 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<root />", 0, &_inner_error_);
#line 199 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		doc = _tmp0_;
#line 199 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1974 "GDocumentTest.c"
			goto __catch156_g_error;
		}
#line 200 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		elem = NULL;
#line 202 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp2_ = doc;
#line 202 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp3_ = gxml_document_create_element ((GXmlDocument*) _tmp2_, "Banana", &_inner_error_);
#line 202 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp1_ = _tmp3_;
#line 202 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 202 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_g_object_unref0 (elem);
#line 202 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_g_object_unref0 (doc);
#line 1991 "GDocumentTest.c"
			goto __catch156_g_error;
		}
#line 202 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp4_ = _tmp1_;
#line 202 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp1_ = NULL;
#line 202 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (elem);
#line 202 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		elem = G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, GXML_TYPE_GELEMENT, GXmlGElement);
#line 203 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp5_ = elem;
#line 203 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp6_ = gxml_dom_element_get_tag_name ((GXmlDomElement*) _tmp5_);
#line 203 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 203 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp8_ = _tmp7_;
#line 203 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp8_, "Banana") == 0, "elem.tag_name == \"Banana\"");
#line 203 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp8_);
#line 204 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp9_ = elem;
#line 204 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp10_ = gxml_dom_element_get_tag_name ((GXmlDomElement*) _tmp9_);
#line 204 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp11_ = _tmp10_;
#line 204 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp12_ = _tmp11_;
#line 204 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp12_, "banana") != 0, "elem.tag_name != \"banana\"");
#line 204 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp12_);
#line 206 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp14_ = doc;
#line 206 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp15_ = gxml_document_create_element ((GXmlDocument*) _tmp14_, "ØÏØÏØ¯ÏØÏ  ²øœ³¤ïØ£", &_inner_error_);
#line 206 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp13_ = _tmp15_;
#line 206 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 206 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_g_object_unref0 (_tmp1_);
#line 206 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_g_object_unref0 (elem);
#line 206 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
			_g_object_unref0 (doc);
#line 2040 "GDocumentTest.c"
			goto __catch156_g_error;
		}
#line 206 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp16_ = _tmp13_;
#line 206 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp13_ = NULL;
#line 206 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (elem);
#line 206 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		elem = G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, GXML_TYPE_GELEMENT, GXmlGElement);
#line 198 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp13_);
#line 198 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp1_);
#line 198 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (elem);
#line 198 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 2059 "GDocumentTest.c"
	}
	goto __finally156;
	__catch156_g_error:
	{
#line 198 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 198 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_inner_error_ = NULL;
#line 207 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_assert_not_reached ();
#line 2070 "GDocumentTest.c"
	}
	__finally156:
#line 198 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 198 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 198 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 198 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		return;
#line 2081 "GDocumentTest.c"
	}
}


static void ___lambda169__gtest_func (void) {
#line 197 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	__lambda169_ ();
#line 2089 "GDocumentTest.c"
}


static void __lambda170_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_ = NULL;
		GXmlText* text = NULL;
		GXmlNode* _tmp1_ = NULL;
		gchar* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
		gchar* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
#line 211 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<root />", 0, &_inner_error_);
#line 211 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		doc = _tmp0_;
#line 211 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2112 "GDocumentTest.c"
			goto __catch157_g_error;
		}
#line 212 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp1_ = gxml_document_create_text ((GXmlDocument*) doc, "Star of my dreams");
#line 212 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		text = G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GXML_TYPE_TEXT, GXmlText);
#line 214 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp2_ = gxml_node_get_name ((GXmlNode*) text);
#line 214 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp3_ = _tmp2_;
#line 214 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp4_ = _tmp3_;
#line 214 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp4_, "#text") == 0, "text.name == \"#text\"");
#line 214 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp4_);
#line 215 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp5_ = gxml_node_get_value ((GXmlNode*) text);
#line 215 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 215 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 215 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp7_, "Star of my dreams") == 0, "text.value == \"Star of my dreams\"");
#line 215 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp7_);
#line 210 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (text);
#line 210 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 2143 "GDocumentTest.c"
	}
	goto __finally157;
	__catch157_g_error:
	{
#line 210 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 210 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_inner_error_ = NULL;
#line 216 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_assert_not_reached ();
#line 2154 "GDocumentTest.c"
	}
	__finally157:
#line 210 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 210 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 210 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 210 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		return;
#line 2165 "GDocumentTest.c"
	}
}


static void ___lambda170__gtest_func (void) {
#line 209 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	__lambda170_ ();
#line 2173 "GDocumentTest.c"
}


static void __lambda171_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_ = NULL;
		GXmlComment* comment = NULL;
		GXmlNode* _tmp1_ = NULL;
		gchar* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
		gchar* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
#line 220 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<root />", 0, &_inner_error_);
#line 220 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		doc = _tmp0_;
#line 220 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2196 "GDocumentTest.c"
			goto __catch158_g_error;
		}
#line 221 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp1_ = gxml_document_create_comment ((GXmlDocument*) doc, "Ever since the day we promised.");
#line 221 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		comment = G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GXML_TYPE_COMMENT, GXmlComment);
#line 223 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp2_ = gxml_node_get_name ((GXmlNode*) comment);
#line 223 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp3_ = _tmp2_;
#line 223 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp4_ = _tmp3_;
#line 223 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp4_, "#comment") == 0, "comment.name == \"#comment\"");
#line 223 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp4_);
#line 224 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp5_ = gxml_comment_get_str (comment);
#line 224 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 224 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 224 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp7_, "Ever since the day we promised.") == 0, "comment.str == \"Ever since the day we promised.\"");
#line 224 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp7_);
#line 219 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (comment);
#line 219 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 2227 "GDocumentTest.c"
	}
	goto __finally158;
	__catch158_g_error:
	{
#line 219 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 219 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_inner_error_ = NULL;
#line 225 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_assert_not_reached ();
#line 2238 "GDocumentTest.c"
	}
	__finally158:
#line 219 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 219 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 219 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 219 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		return;
#line 2249 "GDocumentTest.c"
	}
}


static void ___lambda171__gtest_func (void) {
#line 218 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	__lambda171_ ();
#line 2257 "GDocumentTest.c"
}


static void __lambda172_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_ = NULL;
		GXmlCDATA* cdata = NULL;
		GXmlNode* _tmp1_ = NULL;
		gchar* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
		gchar* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
#line 229 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<root />", 0, &_inner_error_);
#line 229 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		doc = _tmp0_;
#line 229 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2280 "GDocumentTest.c"
			goto __catch159_g_error;
		}
#line 230 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp1_ = gxml_document_create_cdata ((GXmlDocument*) doc, "put in real cdata");
#line 230 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		cdata = G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GXML_TYPE_CDATA, GXmlCDATA);
#line 232 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp2_ = gxml_node_get_name ((GXmlNode*) cdata);
#line 232 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp3_ = _tmp2_;
#line 232 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp4_ = _tmp3_;
#line 232 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp4_, "#cdata-section") == 0, "cdata.name == \"#cdata-section\"");
#line 232 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp4_);
#line 233 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp5_ = gxml_node_get_value ((GXmlNode*) cdata);
#line 233 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 233 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 233 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp7_, "put in real cdata") == 0, "cdata.value == \"put in real cdata\"");
#line 233 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp7_);
#line 228 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (cdata);
#line 228 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 2311 "GDocumentTest.c"
	}
	goto __finally159;
	__catch159_g_error:
	{
#line 228 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 228 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_inner_error_ = NULL;
#line 234 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_assert_not_reached ();
#line 2322 "GDocumentTest.c"
	}
	__finally159:
#line 228 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 228 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 228 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 228 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		return;
#line 2333 "GDocumentTest.c"
	}
}


static void ___lambda172__gtest_func (void) {
#line 227 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	__lambda172_ ();
#line 2341 "GDocumentTest.c"
}


static void __lambda173_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_ = NULL;
		GXmlProcessingInstruction* instruction = NULL;
		GXmlNode* _tmp1_ = NULL;
		gchar* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
		gchar* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
		gchar* _tmp12_ = NULL;
		gchar* _tmp13_ = NULL;
#line 238 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<root />", 0, &_inner_error_);
#line 238 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		doc = _tmp0_;
#line 238 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2370 "GDocumentTest.c"
			goto __catch160_g_error;
		}
#line 239 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp1_ = gxml_document_create_pi ((GXmlDocument*) doc, "target", "data");
#line 239 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		instruction = G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GXML_TYPE_PROCESSING_INSTRUCTION, GXmlProcessingInstruction);
#line 241 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp2_ = gxml_node_get_name ((GXmlNode*) instruction);
#line 241 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp3_ = _tmp2_;
#line 241 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp4_ = _tmp3_;
#line 241 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp4_, "target") == 0, "instruction.name == \"target\"");
#line 241 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp4_);
#line 242 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp5_ = gxml_processing_instruction_get_target (instruction);
#line 242 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 242 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 242 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp7_, "target") == 0, "instruction.target == \"target\"");
#line 242 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp7_);
#line 243 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp8_ = gxml_processing_instruction_get_data (instruction);
#line 243 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 243 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp10_ = _tmp9_;
#line 243 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp10_, "data") == 0, "instruction.data == \"data\"");
#line 243 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp10_);
#line 244 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp11_ = gxml_node_get_value ((GXmlNode*) instruction);
#line 244 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp12_ = _tmp11_;
#line 244 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp13_ = _tmp12_;
#line 244 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp13_, "data") == 0, "instruction.value == \"data\"");
#line 244 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp13_);
#line 237 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (instruction);
#line 237 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 2421 "GDocumentTest.c"
	}
	goto __finally160;
	__catch160_g_error:
	{
#line 237 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 237 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_inner_error_ = NULL;
#line 245 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_assert_not_reached ();
#line 2432 "GDocumentTest.c"
	}
	__finally160:
#line 237 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 237 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 237 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 237 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		return;
#line 2443 "GDocumentTest.c"
	}
}


static void ___lambda173__gtest_func (void) {
#line 236 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	__lambda173_ ();
#line 2451 "GDocumentTest.c"
}


static void __lambda174_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_ = NULL;
		GXmlNode* _tmp1_ = NULL;
		GXmlNode* _tmp2_ = NULL;
		GXmlNode* _tmp3_ = NULL;
		GXmlNode* _tmp4_ = NULL;
		GXmlNode* _tmp5_ = NULL;
		GXmlGElement* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		GXmlNode* attr = NULL;
		GXmlNode* _tmp11_ = NULL;
		GXmlNode* _tmp12_ = NULL;
		GXmlGElement* _tmp13_ = NULL;
		GXmlNode* _tmp14_ = NULL;
		GXmlNode* _tmp15_ = NULL;
		gchar* _tmp16_ = NULL;
		gchar* _tmp17_ = NULL;
		gchar* _tmp18_ = NULL;
		gchar* _tmp19_ = NULL;
		gchar* _tmp20_ = NULL;
		gchar* _tmp21_ = NULL;
		gchar* _tmp22_ = NULL;
		gchar* _tmp23_ = NULL;
		gchar* _tmp24_ = NULL;
		gchar* _tmp25_ = NULL;
		gchar* _tmp26_ = NULL;
		gchar* _tmp27_ = NULL;
		gchar* _tmp28_ = NULL;
		gchar* _tmp29_ = NULL;
		gchar* _tmp30_ = NULL;
		gchar* _tmp31_ = NULL;
#line 249 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<root />", 0, &_inner_error_);
#line 249 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		doc = _tmp0_;
#line 249 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2498 "GDocumentTest.c"
			goto __catch161_g_error;
		}
#line 250 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp1_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 250 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp2_ = _tmp1_;
#line 250 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp3_ = _tmp2_;
#line 250 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (_tmp3_ != NULL, "doc.root != null");
#line 250 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp3_);
#line 251 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp4_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 251 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp5_ = _tmp4_;
#line 251 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp6_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, GXML_TYPE_GELEMENT, GXmlGElement);
#line 251 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		gxml_element_set_attr ((GXmlElement*) _tmp6_, "attrname", "attrvalue");
#line 251 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp6_);
#line 252 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp7_ = gxml_gnode_to_string ((GXmlGNode*) doc);
#line 252 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp8_ = _tmp7_;
#line 252 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp9_ = g_strconcat ("DOC:", _tmp8_, NULL);
#line 252 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp10_ = _tmp9_;
#line 252 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_test_message ("%s", _tmp10_);
#line 252 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp10_);
#line 252 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp8_);
#line 253 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp11_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 253 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp12_ = _tmp11_;
#line 253 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp13_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, GXML_TYPE_GELEMENT, GXmlGElement);
#line 253 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp14_ = gxml_element_get_attr ((GXmlElement*) _tmp13_, "attrname");
#line 253 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp15_ = _tmp14_;
#line 253 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp13_);
#line 253 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		attr = _tmp15_;
#line 254 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp16_ = gxml_node_get_name (attr);
#line 254 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp17_ = _tmp16_;
#line 254 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp18_ = _tmp17_;
#line 254 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp19_ = g_strconcat ("Attr name: ", _tmp18_, NULL);
#line 254 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp20_ = _tmp19_;
#line 254 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_test_message ("%s", _tmp20_);
#line 254 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp20_);
#line 254 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp18_);
#line 255 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp21_ = gxml_node_get_value (attr);
#line 255 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp22_ = _tmp21_;
#line 255 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 255 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp24_ = g_strconcat ("Attr value: ", _tmp23_, NULL);
#line 255 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp25_ = _tmp24_;
#line 255 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_test_message ("%s", _tmp25_);
#line 255 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp25_);
#line 255 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp23_);
#line 256 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (attr != NULL, "attr != null");
#line 257 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (attr, GXML_TYPE_GATTRIBUTE), "attr is GAttribute");
#line 258 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp26_ = gxml_node_get_name (attr);
#line 258 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp27_ = _tmp26_;
#line 258 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp28_ = _tmp27_;
#line 258 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp28_, "attrname") == 0, "attr.name == \"attrname\"");
#line 258 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp28_);
#line 259 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp29_ = gxml_node_get_value (attr);
#line 259 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp30_ = _tmp29_;
#line 259 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp31_ = _tmp30_;
#line 259 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp31_, "attrvalue") == 0, "attr.value == \"attrvalue\"");
#line 259 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp31_);
#line 248 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (attr);
#line 248 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 2609 "GDocumentTest.c"
	}
	goto __finally161;
	__catch161_g_error:
	{
#line 248 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 248 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_inner_error_ = NULL;
#line 262 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_assert_not_reached ();
#line 2620 "GDocumentTest.c"
	}
	__finally161:
#line 248 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 248 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 248 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 248 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		return;
#line 2631 "GDocumentTest.c"
	}
}


static void ___lambda174__gtest_func (void) {
#line 247 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	__lambda174_ ();
#line 2639 "GDocumentTest.c"
}


static void __lambda175_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_ = NULL;
		gchar* s1 = NULL;
		gchar* _tmp1_ = NULL;
		gchar** cs1 = NULL;
		gchar** _tmp2_ = NULL;
		gchar** _tmp3_ = NULL;
		gint cs1_length1 = 0;
		gint _cs1_size_ = 0;
		const gchar* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
#line 266 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"<Sentences><Sentence lang=\"en\">I like the colour blue.</Sentence><Se" \
"ntence lang=\"de\">Ich liebe die T&#xFC;r.</Sentence><Authors><Author>" \
"<Name>Fred</Name><Email>fweasley@hogwarts.co.uk</Email></Author><Autho" \
"r><Name>George</Name><Email>gweasley@hogwarts.co.uk</Email></Author></" \
"Authors></Sentences>", 0, &_inner_error_);
#line 266 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		doc = _tmp0_;
#line 266 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2663 "GDocumentTest.c"
			goto __catch162_g_error;
		}
#line 268 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp1_ = gxml_gnode_to_string ((GXmlGNode*) doc);
#line 268 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		s1 = _tmp1_;
#line 269 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp3_ = _tmp2_ = g_strsplit (s1, "\n", 0);
#line 269 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		cs1 = _tmp3_;
#line 269 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		cs1_length1 = _vala_array_length (_tmp2_);
#line 269 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_cs1_size_ = cs1_length1;
#line 270 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_test_message ("%s", s1);
#line 271 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp4_ = cs1[0];
#line 271 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp4_, "<?xml version=\"1.0\"?>") == 0, "cs1[0] == \"<?xml version=\\\"1.0\\\"?>\"");
#line 272 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp5_ = cs1[1];
#line 272 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp5_, "<Sentences><Sentence lang=\"en\">I like the colour blue.</Sentence><Se" \
"ntence lang=\"de\">Ich liebe die T&#xFC;r.</Sentence><Authors><Author>" \
"<Name>Fred</Name><Email>fweasley@hogwarts.co.uk</Email></Author><Autho" \
"r><Name>George</Name><Email>gweasley@hogwarts.co.uk</Email></Author></" \
"Authors></Sentences>") == 0, "cs1[1] == \"<Sentences><Sentence lang=\\\"en\\\">I like the colour blue.</Sentence><Sentence lang=\\\"de\\\">Ich liebe die T&#xFC;r.</Sentence><Authors><Author><Name>Fred</Name><Email>fweasley@hogwarts.co.uk</Email></Author><Author><Name>George</Name><Email>gweasley@hogwarts.co.uk</Email></Author></Authors></Sentences>\"");
#line 265 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		cs1 = (_vala_array_free (cs1, cs1_length1, (GDestroyNotify) g_free), NULL);
#line 265 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (s1);
#line 265 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 2694 "GDocumentTest.c"
	}
	goto __finally162;
	__catch162_g_error:
	{
#line 265 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 265 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_inner_error_ = NULL;
#line 273 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_assert_not_reached ();
#line 2705 "GDocumentTest.c"
	}
	__finally162:
#line 265 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 265 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 265 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 265 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		return;
#line 2716 "GDocumentTest.c"
	}
}


static void ___lambda175__gtest_func (void) {
#line 264 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	__lambda175_ ();
#line 2724 "GDocumentTest.c"
}


static void __lambda176_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGDocument* d = NULL;
		GXmlGDocument* _tmp0_ = NULL;
		gchar* _tmp1_ = NULL;
		gchar* _tmp2_ = NULL;
		GXmlNode* _tmp3_ = NULL;
		GXmlNode* _tmp4_ = NULL;
		GXmlNode* _tmp5_ = NULL;
		GXmlNode* _tmp6_ = NULL;
		GXmlNode* _tmp7_ = NULL;
		GXmlNode* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
		GXmlNode* _tmp12_ = NULL;
		GXmlNode* _tmp13_ = NULL;
		GXmlNode* _tmp14_ = NULL;
		GeeBidirList* _tmp15_ = NULL;
		GeeBidirList* _tmp16_ = NULL;
		GeeBidirList* _tmp17_ = NULL;
		gint _tmp18_ = 0;
		gint _tmp19_ = 0;
		gchar* _tmp20_ = NULL;
		gchar* _tmp21_ = NULL;
		GXmlNode* _tmp22_ = NULL;
		GXmlNode* _tmp23_ = NULL;
		GXmlNode* _tmp24_ = NULL;
		GeeBidirList* _tmp25_ = NULL;
		GeeBidirList* _tmp26_ = NULL;
		GeeBidirList* _tmp27_ = NULL;
		gpointer _tmp28_ = NULL;
		GXmlNode* _tmp29_ = NULL;
		GXmlNode* _tmp30_ = NULL;
		GXmlNode* _tmp31_ = NULL;
		GXmlNode* _tmp32_ = NULL;
		GeeBidirList* _tmp33_ = NULL;
		GeeBidirList* _tmp34_ = NULL;
		GeeBidirList* _tmp35_ = NULL;
		gpointer _tmp36_ = NULL;
		GXmlNode* _tmp37_ = NULL;
		GXmlNode* _tmp38_ = NULL;
		GXmlNode* _tmp39_ = NULL;
		GXmlNode* _tmp40_ = NULL;
		GeeBidirList* _tmp41_ = NULL;
		GeeBidirList* _tmp42_ = NULL;
		GeeBidirList* _tmp43_ = NULL;
		gpointer _tmp44_ = NULL;
		GXmlNode* _tmp45_ = NULL;
		GXmlNode* _tmp46_ = NULL;
		GXmlNode* _tmp47_ = NULL;
		GXmlNode* _tmp48_ = NULL;
		GeeBidirList* _tmp49_ = NULL;
		GeeBidirList* _tmp50_ = NULL;
		GeeBidirList* _tmp51_ = NULL;
		gpointer _tmp52_ = NULL;
		GXmlNode* _tmp53_ = NULL;
		gchar* _tmp54_ = NULL;
		gchar* _tmp55_ = NULL;
		gchar* _tmp56_ = NULL;
		GXmlNode* _tmp57_ = NULL;
		GXmlNode* _tmp58_ = NULL;
		GXmlNode* _tmp59_ = NULL;
		GeeBidirList* _tmp60_ = NULL;
		GeeBidirList* _tmp61_ = NULL;
		GeeBidirList* _tmp62_ = NULL;
		gint _tmp63_ = 0;
		gint _tmp64_ = 0;
		GXmlNode* _tmp65_ = NULL;
		GXmlNode* _tmp66_ = NULL;
		GXmlNode* _tmp67_ = NULL;
		GeeBidirList* _tmp68_ = NULL;
		GeeBidirList* _tmp69_ = NULL;
		GeeBidirList* _tmp70_ = NULL;
		gpointer _tmp71_ = NULL;
		GXmlNode* _tmp72_ = NULL;
		gchar* _tmp73_ = NULL;
		gchar* _tmp74_ = NULL;
		gchar* _tmp75_ = NULL;
		GXmlNode* _tmp76_ = NULL;
		GXmlNode* _tmp77_ = NULL;
		GXmlNode* _tmp78_ = NULL;
		GeeBidirList* _tmp79_ = NULL;
		GeeBidirList* _tmp80_ = NULL;
		GeeBidirList* _tmp81_ = NULL;
		gpointer _tmp82_ = NULL;
		GXmlNode* _tmp83_ = NULL;
		GeeBidirList* _tmp84_ = NULL;
		GeeBidirList* _tmp85_ = NULL;
		GeeBidirList* _tmp86_ = NULL;
		gint _tmp87_ = 0;
		gint _tmp88_ = 0;
		GXmlNode* _tmp89_ = NULL;
		GXmlNode* _tmp90_ = NULL;
		GXmlNode* _tmp91_ = NULL;
		GeeBidirList* _tmp92_ = NULL;
		GeeBidirList* _tmp93_ = NULL;
		GeeBidirList* _tmp94_ = NULL;
		gpointer _tmp95_ = NULL;
		GXmlNode* _tmp96_ = NULL;
		GeeBidirList* _tmp97_ = NULL;
		GeeBidirList* _tmp98_ = NULL;
		GeeBidirList* _tmp99_ = NULL;
		gpointer _tmp100_ = NULL;
		GXmlNode* _tmp101_ = NULL;
		gchar* _tmp102_ = NULL;
		gchar* _tmp103_ = NULL;
		gchar* _tmp104_ = NULL;
		GXmlNode* _tmp105_ = NULL;
		GXmlNode* _tmp106_ = NULL;
		GXmlNode* _tmp107_ = NULL;
		GeeBidirList* _tmp108_ = NULL;
		GeeBidirList* _tmp109_ = NULL;
		GeeBidirList* _tmp110_ = NULL;
		gpointer _tmp111_ = NULL;
		GXmlNode* _tmp112_ = NULL;
		GeeBidirList* _tmp113_ = NULL;
		GeeBidirList* _tmp114_ = NULL;
		GeeBidirList* _tmp115_ = NULL;
		gpointer _tmp116_ = NULL;
		GXmlNode* _tmp117_ = NULL;
		GeeBidirList* _tmp118_ = NULL;
		GeeBidirList* _tmp119_ = NULL;
		GeeBidirList* _tmp120_ = NULL;
		gint _tmp121_ = 0;
		gint _tmp122_ = 0;
		GXmlNode* _tmp123_ = NULL;
		GXmlNode* _tmp124_ = NULL;
		GXmlNode* _tmp125_ = NULL;
		GeeBidirList* _tmp126_ = NULL;
		GeeBidirList* _tmp127_ = NULL;
		GeeBidirList* _tmp128_ = NULL;
		gpointer _tmp129_ = NULL;
		GXmlNode* _tmp130_ = NULL;
		GeeBidirList* _tmp131_ = NULL;
		GeeBidirList* _tmp132_ = NULL;
		GeeBidirList* _tmp133_ = NULL;
		gpointer _tmp134_ = NULL;
		GXmlNode* _tmp135_ = NULL;
		GeeBidirList* _tmp136_ = NULL;
		GeeBidirList* _tmp137_ = NULL;
		GeeBidirList* _tmp138_ = NULL;
		gpointer _tmp139_ = NULL;
		GXmlNode* _tmp140_ = NULL;
		gchar* _tmp141_ = NULL;
		gchar* _tmp142_ = NULL;
		gchar* _tmp143_ = NULL;
		GXmlNode* _tmp144_ = NULL;
		GXmlNode* _tmp145_ = NULL;
		GXmlNode* _tmp146_ = NULL;
		GeeBidirList* _tmp147_ = NULL;
		GeeBidirList* _tmp148_ = NULL;
		GeeBidirList* _tmp149_ = NULL;
		gpointer _tmp150_ = NULL;
		GXmlNode* _tmp151_ = NULL;
		GeeBidirList* _tmp152_ = NULL;
		GeeBidirList* _tmp153_ = NULL;
		GeeBidirList* _tmp154_ = NULL;
		gpointer _tmp155_ = NULL;
		GXmlNode* _tmp156_ = NULL;
		GeeBidirList* _tmp157_ = NULL;
		GeeBidirList* _tmp158_ = NULL;
		GeeBidirList* _tmp159_ = NULL;
		gpointer _tmp160_ = NULL;
		GXmlNode* _tmp161_ = NULL;
		GeeBidirList* _tmp162_ = NULL;
		GeeBidirList* _tmp163_ = NULL;
		GeeBidirList* _tmp164_ = NULL;
		gint _tmp165_ = 0;
		gint _tmp166_ = 0;
		GXmlNode* _tmp167_ = NULL;
		GXmlNode* _tmp168_ = NULL;
		GXmlNode* _tmp169_ = NULL;
		GeeBidirList* _tmp170_ = NULL;
		GeeBidirList* _tmp171_ = NULL;
		GeeBidirList* _tmp172_ = NULL;
		gpointer _tmp173_ = NULL;
		GXmlNode* _tmp174_ = NULL;
		GeeBidirList* _tmp175_ = NULL;
		GeeBidirList* _tmp176_ = NULL;
		GeeBidirList* _tmp177_ = NULL;
		gpointer _tmp178_ = NULL;
		GXmlNode* _tmp179_ = NULL;
		GeeBidirList* _tmp180_ = NULL;
		GeeBidirList* _tmp181_ = NULL;
		GeeBidirList* _tmp182_ = NULL;
		gpointer _tmp183_ = NULL;
		GXmlNode* _tmp184_ = NULL;
		GeeBidirList* _tmp185_ = NULL;
		GeeBidirList* _tmp186_ = NULL;
		GeeBidirList* _tmp187_ = NULL;
		gpointer _tmp188_ = NULL;
		GXmlNode* _tmp189_ = NULL;
		GXmlNode* _tmp190_ = NULL;
		GXmlNode* _tmp191_ = NULL;
		GXmlNode* _tmp192_ = NULL;
		GeeBidirList* _tmp193_ = NULL;
		GeeBidirList* _tmp194_ = NULL;
		GeeBidirList* _tmp195_ = NULL;
		gpointer _tmp196_ = NULL;
		GXmlNode* _tmp197_ = NULL;
		GeeBidirList* _tmp198_ = NULL;
		GeeBidirList* _tmp199_ = NULL;
		GeeBidirList* _tmp200_ = NULL;
		gpointer _tmp201_ = NULL;
		GXmlNode* _tmp202_ = NULL;
		GeeBidirList* _tmp203_ = NULL;
		GeeBidirList* _tmp204_ = NULL;
		GeeBidirList* _tmp205_ = NULL;
		gpointer _tmp206_ = NULL;
		GXmlNode* _tmp207_ = NULL;
		GeeBidirList* _tmp208_ = NULL;
		GeeBidirList* _tmp209_ = NULL;
		GeeBidirList* _tmp210_ = NULL;
		gpointer _tmp211_ = NULL;
		GXmlNode* _tmp212_ = NULL;
		gchar* _tmp213_ = NULL;
		gchar* _tmp214_ = NULL;
		gchar* _tmp215_ = NULL;
#line 277 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp0_ = gxml_gdocument_new_from_path (TEST_DIR "/gdocument-read.xml", 0, &_inner_error_);
#line 277 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		d = _tmp0_;
#line 277 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2954 "GDocumentTest.c"
			goto __catch163_g_error;
		}
#line 278 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp1_ = gxml_gnode_to_string ((GXmlGNode*) d);
#line 278 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp2_ = _tmp1_;
#line 278 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_test_message ("%s", _tmp2_);
#line 278 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp2_);
#line 279 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp3_ = gxml_document_get_root ((GXmlDocument*) d);
#line 279 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp4_ = _tmp3_;
#line 279 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp5_ = _tmp4_;
#line 279 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (_tmp5_ != NULL, "d.root != null");
#line 279 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp5_);
#line 280 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp6_ = gxml_document_get_root ((GXmlDocument*) d);
#line 280 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 280 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp8_ = _tmp7_;
#line 280 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp9_ = gxml_node_get_name (_tmp8_);
#line 280 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp10_ = _tmp9_;
#line 280 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp11_ = _tmp10_;
#line 280 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp11_, "DataTypeTemplates") == 0, "d.root.name == \"DataTypeTemplates\"");
#line 280 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp11_);
#line 280 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp8_);
#line 281 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp12_ = gxml_document_get_root ((GXmlDocument*) d);
#line 281 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp13_ = _tmp12_;
#line 281 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp14_ = _tmp13_;
#line 281 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp15_ = gxml_node_get_children_nodes (_tmp14_);
#line 281 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp16_ = _tmp15_;
#line 281 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp17_ = _tmp16_;
#line 281 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp18_ = gee_collection_get_size ((GeeCollection*) _tmp17_);
#line 281 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp19_ = _tmp18_;
#line 281 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp20_ = g_strdup_printf ("%i", _tmp19_);
#line 281 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp21_ = _tmp20_;
#line 281 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_test_message ("%s", _tmp21_);
#line 281 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp21_);
#line 281 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp17_);
#line 281 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp14_);
#line 282 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp22_ = gxml_document_get_root ((GXmlDocument*) d);
#line 282 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 282 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp24_ = _tmp23_;
#line 282 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp25_ = gxml_node_get_children_nodes (_tmp24_);
#line 282 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp26_ = _tmp25_;
#line 282 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp27_ = _tmp26_;
#line 282 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp28_ = gee_list_get ((GeeList*) _tmp27_, 0);
#line 282 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp29_ = (GXmlNode*) _tmp28_;
#line 282 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp29_, GXML_TYPE_TEXT), "d.root.children_nodes[0] is GXml.Text");
#line 282 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp29_);
#line 282 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp27_);
#line 282 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp24_);
#line 283 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp30_ = gxml_document_get_root ((GXmlDocument*) d);
#line 283 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp31_ = _tmp30_;
#line 283 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp32_ = _tmp31_;
#line 283 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp33_ = gxml_node_get_children_nodes (_tmp32_);
#line 283 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp34_ = _tmp33_;
#line 283 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp35_ = _tmp34_;
#line 283 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp36_ = gee_list_get ((GeeList*) _tmp35_, 1);
#line 283 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp37_ = (GXmlNode*) _tmp36_;
#line 283 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp37_, GXML_TYPE_ELEMENT), "d.root.children_nodes[1] is GXml.Element");
#line 283 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp37_);
#line 283 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp35_);
#line 283 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp32_);
#line 284 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp38_ = gxml_document_get_root ((GXmlDocument*) d);
#line 284 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp39_ = _tmp38_;
#line 284 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp40_ = _tmp39_;
#line 284 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp41_ = gxml_node_get_children_nodes (_tmp40_);
#line 284 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp42_ = _tmp41_;
#line 284 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp43_ = _tmp42_;
#line 284 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp44_ = gee_list_get ((GeeList*) _tmp43_, 2);
#line 284 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp45_ = (GXmlNode*) _tmp44_;
#line 284 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp45_, GXML_TYPE_TEXT), "d.root.children_nodes[2] is GXml.Text");
#line 284 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp45_);
#line 284 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp43_);
#line 284 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp40_);
#line 285 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp46_ = gxml_document_get_root ((GXmlDocument*) d);
#line 285 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp47_ = _tmp46_;
#line 285 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp48_ = _tmp47_;
#line 285 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp49_ = gxml_node_get_children_nodes (_tmp48_);
#line 285 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp50_ = _tmp49_;
#line 285 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp51_ = _tmp50_;
#line 285 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp52_ = gee_list_get ((GeeList*) _tmp51_, 2);
#line 285 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp53_ = (GXmlNode*) _tmp52_;
#line 285 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp54_ = gxml_node_get_value (_tmp53_);
#line 285 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp55_ = _tmp54_;
#line 285 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp56_ = _tmp55_;
#line 285 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp56_, "\n") == 0, "d.root.children_nodes[2].value == \"\\n\"");
#line 285 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp56_);
#line 285 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp53_);
#line 285 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp51_);
#line 285 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp48_);
#line 286 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp57_ = gxml_document_get_root ((GXmlDocument*) d);
#line 286 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp58_ = _tmp57_;
#line 286 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp59_ = _tmp58_;
#line 286 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp60_ = gxml_node_get_children_nodes (_tmp59_);
#line 286 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp61_ = _tmp60_;
#line 286 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp62_ = _tmp61_;
#line 286 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp63_ = gee_collection_get_size ((GeeCollection*) _tmp62_);
#line 286 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp64_ = _tmp63_;
#line 286 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (_tmp64_ == 3, "d.root.children_nodes.size == 3");
#line 286 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp62_);
#line 286 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp59_);
#line 287 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp65_ = gxml_document_get_root ((GXmlDocument*) d);
#line 287 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp66_ = _tmp65_;
#line 287 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp67_ = _tmp66_;
#line 287 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp68_ = gxml_node_get_children_nodes (_tmp67_);
#line 287 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp69_ = _tmp68_;
#line 287 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp70_ = _tmp69_;
#line 287 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp71_ = gee_list_get ((GeeList*) _tmp70_, 1);
#line 287 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp72_ = (GXmlNode*) _tmp71_;
#line 287 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp73_ = gxml_node_get_name (_tmp72_);
#line 287 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp74_ = _tmp73_;
#line 287 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp75_ = _tmp74_;
#line 287 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp75_, "DAType") == 0, "d.root.children_nodes[1].name == \"DAType\"");
#line 287 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp75_);
#line 287 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp72_);
#line 287 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp70_);
#line 287 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp67_);
#line 288 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp76_ = gxml_document_get_root ((GXmlDocument*) d);
#line 288 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp77_ = _tmp76_;
#line 288 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp78_ = _tmp77_;
#line 288 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp79_ = gxml_node_get_children_nodes (_tmp78_);
#line 288 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp80_ = _tmp79_;
#line 288 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp81_ = _tmp80_;
#line 288 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp82_ = gee_list_get ((GeeList*) _tmp81_, 1);
#line 288 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp83_ = (GXmlNode*) _tmp82_;
#line 288 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp84_ = gxml_node_get_children_nodes (_tmp83_);
#line 288 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp85_ = _tmp84_;
#line 288 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp86_ = _tmp85_;
#line 288 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp87_ = gee_collection_get_size ((GeeCollection*) _tmp86_);
#line 288 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp88_ = _tmp87_;
#line 288 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (_tmp88_ == 3, "d.root.children_nodes[1].children_nodes.size == 3");
#line 288 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp86_);
#line 288 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp83_);
#line 288 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp81_);
#line 288 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp78_);
#line 289 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp89_ = gxml_document_get_root ((GXmlDocument*) d);
#line 289 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp90_ = _tmp89_;
#line 289 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp91_ = _tmp90_;
#line 289 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp92_ = gxml_node_get_children_nodes (_tmp91_);
#line 289 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp93_ = _tmp92_;
#line 289 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp94_ = _tmp93_;
#line 289 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp95_ = gee_list_get ((GeeList*) _tmp94_, 1);
#line 289 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp96_ = (GXmlNode*) _tmp95_;
#line 289 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp97_ = gxml_node_get_children_nodes (_tmp96_);
#line 289 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp98_ = _tmp97_;
#line 289 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp99_ = _tmp98_;
#line 289 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp100_ = gee_list_get ((GeeList*) _tmp99_, 1);
#line 289 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp101_ = (GXmlNode*) _tmp100_;
#line 289 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp102_ = gxml_node_get_name (_tmp101_);
#line 289 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp103_ = _tmp102_;
#line 289 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp104_ = _tmp103_;
#line 289 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp104_, "BDA") == 0, "d.root.children_nodes[1].children_nodes[1].name == \"BDA\"");
#line 289 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp104_);
#line 289 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp101_);
#line 289 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp99_);
#line 289 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp96_);
#line 289 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp94_);
#line 289 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp91_);
#line 290 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp105_ = gxml_document_get_root ((GXmlDocument*) d);
#line 290 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp106_ = _tmp105_;
#line 290 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp107_ = _tmp106_;
#line 290 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp108_ = gxml_node_get_children_nodes (_tmp107_);
#line 290 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp109_ = _tmp108_;
#line 290 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp110_ = _tmp109_;
#line 290 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp111_ = gee_list_get ((GeeList*) _tmp110_, 1);
#line 290 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp112_ = (GXmlNode*) _tmp111_;
#line 290 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp113_ = gxml_node_get_children_nodes (_tmp112_);
#line 290 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp114_ = _tmp113_;
#line 290 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp115_ = _tmp114_;
#line 290 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp116_ = gee_list_get ((GeeList*) _tmp115_, 1);
#line 290 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp117_ = (GXmlNode*) _tmp116_;
#line 290 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp118_ = gxml_node_get_children_nodes (_tmp117_);
#line 290 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp119_ = _tmp118_;
#line 290 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp120_ = _tmp119_;
#line 290 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp121_ = gee_collection_get_size ((GeeCollection*) _tmp120_);
#line 290 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp122_ = _tmp121_;
#line 290 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (_tmp122_ == 3, "d.root.children_nodes[1].children_nodes[1].children_nodes.size == 3");
#line 290 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp120_);
#line 290 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp117_);
#line 290 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp115_);
#line 290 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp112_);
#line 290 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp110_);
#line 290 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp107_);
#line 291 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp123_ = gxml_document_get_root ((GXmlDocument*) d);
#line 291 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp124_ = _tmp123_;
#line 291 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp125_ = _tmp124_;
#line 291 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp126_ = gxml_node_get_children_nodes (_tmp125_);
#line 291 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp127_ = _tmp126_;
#line 291 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp128_ = _tmp127_;
#line 291 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp129_ = gee_list_get ((GeeList*) _tmp128_, 1);
#line 291 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp130_ = (GXmlNode*) _tmp129_;
#line 291 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp131_ = gxml_node_get_children_nodes (_tmp130_);
#line 291 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp132_ = _tmp131_;
#line 291 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp133_ = _tmp132_;
#line 291 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp134_ = gee_list_get ((GeeList*) _tmp133_, 1);
#line 291 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp135_ = (GXmlNode*) _tmp134_;
#line 291 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp136_ = gxml_node_get_children_nodes (_tmp135_);
#line 291 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp137_ = _tmp136_;
#line 291 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp138_ = _tmp137_;
#line 291 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp139_ = gee_list_get ((GeeList*) _tmp138_, 1);
#line 291 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp140_ = (GXmlNode*) _tmp139_;
#line 291 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp141_ = gxml_node_get_name (_tmp140_);
#line 291 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp142_ = _tmp141_;
#line 291 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp143_ = _tmp142_;
#line 291 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp143_, "Val") == 0, "d.root.children_nodes[1].children_nodes[1].children_nodes[1].name == \"Val\"");
#line 291 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp143_);
#line 291 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp140_);
#line 291 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp138_);
#line 291 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp135_);
#line 291 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp133_);
#line 291 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp130_);
#line 291 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp128_);
#line 291 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp125_);
#line 292 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp144_ = gxml_document_get_root ((GXmlDocument*) d);
#line 292 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp145_ = _tmp144_;
#line 292 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp146_ = _tmp145_;
#line 292 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp147_ = gxml_node_get_children_nodes (_tmp146_);
#line 292 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp148_ = _tmp147_;
#line 292 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp149_ = _tmp148_;
#line 292 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp150_ = gee_list_get ((GeeList*) _tmp149_, 1);
#line 292 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp151_ = (GXmlNode*) _tmp150_;
#line 292 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp152_ = gxml_node_get_children_nodes (_tmp151_);
#line 292 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp153_ = _tmp152_;
#line 292 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp154_ = _tmp153_;
#line 292 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp155_ = gee_list_get ((GeeList*) _tmp154_, 1);
#line 292 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp156_ = (GXmlNode*) _tmp155_;
#line 292 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp157_ = gxml_node_get_children_nodes (_tmp156_);
#line 292 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp158_ = _tmp157_;
#line 292 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp159_ = _tmp158_;
#line 292 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp160_ = gee_list_get ((GeeList*) _tmp159_, 1);
#line 292 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp161_ = (GXmlNode*) _tmp160_;
#line 292 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp162_ = gxml_node_get_children_nodes (_tmp161_);
#line 292 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp163_ = _tmp162_;
#line 292 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp164_ = _tmp163_;
#line 292 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp165_ = gee_collection_get_size ((GeeCollection*) _tmp164_);
#line 292 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp166_ = _tmp165_;
#line 292 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (_tmp166_ == 1, "d.root.children_nodes[1].children_nodes[1].children_nodes[1].children_nodes.size == 1");
#line 292 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp164_);
#line 292 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp161_);
#line 292 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp159_);
#line 292 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp156_);
#line 292 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp154_);
#line 292 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp151_);
#line 292 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp149_);
#line 292 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp146_);
#line 293 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp167_ = gxml_document_get_root ((GXmlDocument*) d);
#line 293 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp168_ = _tmp167_;
#line 293 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp169_ = _tmp168_;
#line 293 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp170_ = gxml_node_get_children_nodes (_tmp169_);
#line 293 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp171_ = _tmp170_;
#line 293 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp172_ = _tmp171_;
#line 293 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp173_ = gee_list_get ((GeeList*) _tmp172_, 1);
#line 293 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp174_ = (GXmlNode*) _tmp173_;
#line 293 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp175_ = gxml_node_get_children_nodes (_tmp174_);
#line 293 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp176_ = _tmp175_;
#line 293 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp177_ = _tmp176_;
#line 293 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp178_ = gee_list_get ((GeeList*) _tmp177_, 1);
#line 293 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp179_ = (GXmlNode*) _tmp178_;
#line 293 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp180_ = gxml_node_get_children_nodes (_tmp179_);
#line 293 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp181_ = _tmp180_;
#line 293 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp182_ = _tmp181_;
#line 293 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp183_ = gee_list_get ((GeeList*) _tmp182_, 1);
#line 293 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp184_ = (GXmlNode*) _tmp183_;
#line 293 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp185_ = gxml_node_get_children_nodes (_tmp184_);
#line 293 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp186_ = _tmp185_;
#line 293 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp187_ = _tmp186_;
#line 293 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp188_ = gee_list_get ((GeeList*) _tmp187_, 0);
#line 293 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp189_ = (GXmlNode*) _tmp188_;
#line 293 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp189_, GXML_TYPE_TEXT), "d.root.children_nodes[1].children_nodes[1].children_nodes[1].children_nodes[0] is GXml.Text");
#line 293 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp189_);
#line 293 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp187_);
#line 293 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp184_);
#line 293 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp182_);
#line 293 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp179_);
#line 293 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp177_);
#line 293 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp174_);
#line 293 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp172_);
#line 293 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp169_);
#line 294 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp190_ = gxml_document_get_root ((GXmlDocument*) d);
#line 294 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp191_ = _tmp190_;
#line 294 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp192_ = _tmp191_;
#line 294 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp193_ = gxml_node_get_children_nodes (_tmp192_);
#line 294 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp194_ = _tmp193_;
#line 294 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp195_ = _tmp194_;
#line 294 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp196_ = gee_list_get ((GeeList*) _tmp195_, 1);
#line 294 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp197_ = (GXmlNode*) _tmp196_;
#line 294 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp198_ = gxml_node_get_children_nodes (_tmp197_);
#line 294 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp199_ = _tmp198_;
#line 294 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp200_ = _tmp199_;
#line 294 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp201_ = gee_list_get ((GeeList*) _tmp200_, 1);
#line 294 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp202_ = (GXmlNode*) _tmp201_;
#line 294 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp203_ = gxml_node_get_children_nodes (_tmp202_);
#line 294 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp204_ = _tmp203_;
#line 294 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp205_ = _tmp204_;
#line 294 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp206_ = gee_list_get ((GeeList*) _tmp205_, 1);
#line 294 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp207_ = (GXmlNode*) _tmp206_;
#line 294 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp208_ = gxml_node_get_children_nodes (_tmp207_);
#line 294 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp209_ = _tmp208_;
#line 294 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp210_ = _tmp209_;
#line 294 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp211_ = gee_list_get ((GeeList*) _tmp210_, 0);
#line 294 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp212_ = (GXmlNode*) _tmp211_;
#line 294 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp213_ = gxml_node_get_value (_tmp212_);
#line 294 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp214_ = _tmp213_;
#line 294 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp215_ = _tmp214_;
#line 294 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp215_, "status_only") == 0, "d.root.children_nodes[1].children_nodes[1].children_nodes[1].children_nodes[0].value == \"status_only\"");
#line 294 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp215_);
#line 294 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp212_);
#line 294 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp210_);
#line 294 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp207_);
#line 294 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp205_);
#line 294 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp202_);
#line 294 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp200_);
#line 294 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp197_);
#line 294 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp195_);
#line 294 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp192_);
#line 276 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (d);
#line 3577 "GDocumentTest.c"
	}
	goto __finally163;
	__catch163_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp216_ = NULL;
		gchar* _tmp217_ = NULL;
		gchar* _tmp218_ = NULL;
#line 276 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		e = _inner_error_;
#line 276 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_inner_error_ = NULL;
#line 295 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp216_ = e->message;
#line 295 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp217_ = g_strconcat ("ERROR: ", _tmp216_, NULL);
#line 295 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp218_ = _tmp217_;
#line 295 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_message ("GDocumentTest.vala:295: %s", _tmp218_);
#line 295 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp218_);
#line 295 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_assert_not_reached ();
#line 276 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_error_free0 (e);
#line 3604 "GDocumentTest.c"
	}
	__finally163:
#line 276 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 276 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 276 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 276 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		return;
#line 3615 "GDocumentTest.c"
	}
}


static void ___lambda176__gtest_func (void) {
#line 275 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	__lambda176_ ();
#line 3623 "GDocumentTest.c"
}


static void __lambda177_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_ = NULL;
		gchar* s1 = NULL;
		gchar* _tmp1_ = NULL;
		gchar** cs1 = NULL;
		gchar** _tmp2_ = NULL;
		gchar** _tmp3_ = NULL;
		gint cs1_length1 = 0;
		gint _cs1_size_ = 0;
		const gchar* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
#line 299 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"<Sentences><Sentence lang=\"en\">I like the colour blue.</Sentence><Se" \
"ntence lang=\"de\">Ich liebe die T&#xFC;r.</Sentence><Authors><Author>" \
"<Name>Fred</Name><Email>fweasley@hogwarts.co.uk</Email></Author><Autho" \
"r><Name>George</Name><Email>gweasley@hogwarts.co.uk</Email></Author></" \
"Authors></Sentences>", 0, &_inner_error_);
#line 299 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		doc = _tmp0_;
#line 299 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3647 "GDocumentTest.c"
			goto __catch164_g_error;
		}
#line 301 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp1_ = gxml_gdocument_libxml_to_string (doc);
#line 301 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		s1 = _tmp1_;
#line 302 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp3_ = _tmp2_ = g_strsplit (s1, "\n", 0);
#line 302 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		cs1 = _tmp3_;
#line 302 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		cs1_length1 = _vala_array_length (_tmp2_);
#line 302 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_cs1_size_ = cs1_length1;
#line 303 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_test_message ("%s", s1);
#line 304 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp4_ = cs1[0];
#line 304 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp4_, "<?xml version=\"1.0\"?>") == 0, "cs1[0] == \"<?xml version=\\\"1.0\\\"?>\"");
#line 305 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp5_ = cs1[1];
#line 305 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp5_, "<Sentences><Sentence lang=\"en\">I like the colour blue.</Sentence><Se" \
"ntence lang=\"de\">Ich liebe die T&#xFC;r.</Sentence><Authors><Author>" \
"<Name>Fred</Name><Email>fweasley@hogwarts.co.uk</Email></Author><Autho" \
"r><Name>George</Name><Email>gweasley@hogwarts.co.uk</Email></Author></" \
"Authors></Sentences>") == 0, "cs1[1] == \"<Sentences><Sentence lang=\\\"en\\\">I like the colour blue.</Sentence><Sentence lang=\\\"de\\\">Ich liebe die T&#xFC;r.</Sentence><Authors><Author><Name>Fred</Name><Email>fweasley@hogwarts.co.uk</Email></Author><Author><Name>George</Name><Email>gweasley@hogwarts.co.uk</Email></Author></Authors></Sentences>\"");
#line 298 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		cs1 = (_vala_array_free (cs1, cs1_length1, (GDestroyNotify) g_free), NULL);
#line 298 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (s1);
#line 298 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 3678 "GDocumentTest.c"
	}
	goto __finally164;
	__catch164_g_error:
	{
#line 298 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 298 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_inner_error_ = NULL;
#line 306 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_assert_not_reached ();
#line 3689 "GDocumentTest.c"
	}
	__finally164:
#line 298 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 298 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 298 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 298 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		return;
#line 3700 "GDocumentTest.c"
	}
}


static void ___lambda177__gtest_func (void) {
#line 297 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	__lambda177_ ();
#line 3708 "GDocumentTest.c"
}


static void __lambda178_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_ = NULL;
		GXmlNode* _tmp1_ = NULL;
		GXmlNode* _tmp2_ = NULL;
		GXmlNode* _tmp3_ = NULL;
		GXmlNode* _tmp4_ = NULL;
		GXmlNode* _tmp5_ = NULL;
		GXmlNode* _tmp6_ = NULL;
		GeeList* _tmp7_ = NULL;
		GeeList* _tmp8_ = NULL;
		GeeList* _tmp9_ = NULL;
		GXmlNode* _tmp10_ = NULL;
		GXmlNode* _tmp11_ = NULL;
		GXmlNode* _tmp12_ = NULL;
		GeeList* _tmp13_ = NULL;
		GeeList* _tmp14_ = NULL;
		GeeList* _tmp15_ = NULL;
		gint _tmp16_ = 0;
		gint _tmp17_ = 0;
		GXmlNode* _tmp18_ = NULL;
		GXmlNode* _tmp19_ = NULL;
		GXmlNode* _tmp20_ = NULL;
		GeeList* _tmp21_ = NULL;
		GeeList* _tmp22_ = NULL;
		GeeList* _tmp23_ = NULL;
		gpointer _tmp24_ = NULL;
		GXmlNamespace* _tmp25_ = NULL;
		gchar* _tmp26_ = NULL;
		gchar* _tmp27_ = NULL;
		gchar* _tmp28_ = NULL;
		GXmlNode* _tmp29_ = NULL;
		GXmlNode* _tmp30_ = NULL;
		GXmlNode* _tmp31_ = NULL;
		GeeList* _tmp32_ = NULL;
		GeeList* _tmp33_ = NULL;
		GeeList* _tmp34_ = NULL;
		gpointer _tmp35_ = NULL;
		GXmlNamespace* _tmp36_ = NULL;
		gchar* _tmp37_ = NULL;
		gchar* _tmp38_ = NULL;
		gchar* _tmp39_ = NULL;
		GXmlNode* _tmp40_ = NULL;
		GXmlNode* _tmp41_ = NULL;
		GXmlNode* _tmp42_ = NULL;
		GeeBidirList* _tmp43_ = NULL;
		GeeBidirList* _tmp44_ = NULL;
		GeeBidirList* _tmp45_ = NULL;
		GXmlNode* _tmp46_ = NULL;
		GXmlNode* _tmp47_ = NULL;
		GXmlNode* _tmp48_ = NULL;
		GeeBidirList* _tmp49_ = NULL;
		GeeBidirList* _tmp50_ = NULL;
		GeeBidirList* _tmp51_ = NULL;
		gint _tmp52_ = 0;
		gint _tmp53_ = 0;
		GXmlNode* c = NULL;
		GXmlNode* _tmp54_ = NULL;
		GXmlNode* _tmp55_ = NULL;
		GXmlNode* _tmp56_ = NULL;
		GeeBidirList* _tmp57_ = NULL;
		GeeBidirList* _tmp58_ = NULL;
		GeeBidirList* _tmp59_ = NULL;
		gpointer _tmp60_ = NULL;
		GXmlNode* _tmp61_ = NULL;
		GeeList* _tmp62_ = NULL;
		GeeList* _tmp63_ = NULL;
		GeeList* _tmp64_ = NULL;
		GeeList* _tmp65_ = NULL;
		GeeList* _tmp66_ = NULL;
		GeeList* _tmp67_ = NULL;
		gint _tmp68_ = 0;
		gint _tmp69_ = 0;
		GeeList* _tmp70_ = NULL;
		GeeList* _tmp71_ = NULL;
		GeeList* _tmp72_ = NULL;
		gpointer _tmp73_ = NULL;
		GXmlNamespace* _tmp74_ = NULL;
		gchar* _tmp75_ = NULL;
		gchar* _tmp76_ = NULL;
		gchar* _tmp77_ = NULL;
		GeeList* _tmp78_ = NULL;
		GeeList* _tmp79_ = NULL;
		GeeList* _tmp80_ = NULL;
		gpointer _tmp81_ = NULL;
		GXmlNamespace* _tmp82_ = NULL;
		gchar* _tmp83_ = NULL;
		gchar* _tmp84_ = NULL;
		gchar* _tmp85_ = NULL;
		GXmlNode* p = NULL;
		GXmlNode* _tmp86_ = NULL;
		GXmlNode* _tmp87_ = NULL;
		GXmlNode* _tmp88_ = NULL;
		GXmlNode* _tmp89_ = NULL;
		gchar* _tmp90_ = NULL;
		gchar* _tmp91_ = NULL;
		gchar* _tmp92_ = NULL;
		gchar* _tmp93_ = NULL;
		GXmlNode* _tmp94_ = NULL;
		GXmlNode* _tmp95_ = NULL;
		GXmlNode* _tmp96_ = NULL;
		gchar* _tmp97_ = NULL;
		gchar* _tmp98_ = NULL;
		GXmlNode* _tmp99_ = NULL;
		GXmlNode* _tmp100_ = NULL;
		GXmlNode* _tmp101_ = NULL;
		GeeList* _tmp102_ = NULL;
		GeeList* _tmp103_ = NULL;
		GeeList* _tmp104_ = NULL;
		gpointer _tmp105_ = NULL;
		GXmlNamespace* _tmp106_ = NULL;
		gchar* _tmp107_ = NULL;
		gchar* _tmp108_ = NULL;
		gchar* _tmp109_ = NULL;
		GXmlNode* _tmp110_ = NULL;
		GXmlNode* _tmp111_ = NULL;
		GXmlNode* _tmp112_ = NULL;
		gchar* _tmp113_ = NULL;
		gchar* _tmp114_ = NULL;
		gchar* _tmp115_ = NULL;
		gchar* _tmp116_ = NULL;
		GeeMap* _tmp117_ = NULL;
		GeeMap* _tmp118_ = NULL;
		GeeMap* _tmp119_ = NULL;
		gint _tmp120_ = 0;
		gint _tmp121_ = 0;
		GXmlNode* pt = NULL;
		GeeMap* _tmp122_ = NULL;
		GeeMap* _tmp123_ = NULL;
		GeeMap* _tmp124_ = NULL;
		gpointer _tmp125_ = NULL;
		GXmlNode* _tmp126_ = NULL;
		GXmlNode* _tmp127_ = NULL;
		GXmlNode* _tmp128_ = NULL;
		GXmlNode* _tmp129_ = NULL;
		gchar* _tmp130_ = NULL;
		gchar* _tmp131_ = NULL;
#line 310 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<root><child/></root>", 0, &_inner_error_);
#line 310 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		doc = _tmp0_;
#line 310 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3857 "GDocumentTest.c"
			goto __catch165_g_error;
		}
#line 311 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		gxml_gnode_set_namespace ((GXmlGNode*) doc, "http://www.gnome.org/GXml", "gxml");
#line 312 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp1_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 312 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp2_ = _tmp1_;
#line 312 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp3_ = _tmp2_;
#line 312 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (_tmp3_ != NULL, "doc.root != null");
#line 312 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp3_);
#line 313 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp4_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 313 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp5_ = _tmp4_;
#line 313 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 313 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp7_ = gxml_node_get_namespaces (_tmp6_);
#line 313 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp8_ = _tmp7_;
#line 313 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 313 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (_tmp9_ != NULL, "doc.root.namespaces != null");
#line 313 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp9_);
#line 313 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp6_);
#line 314 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp10_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 314 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp11_ = _tmp10_;
#line 314 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp12_ = _tmp11_;
#line 314 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp13_ = gxml_node_get_namespaces (_tmp12_);
#line 314 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp14_ = _tmp13_;
#line 314 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp15_ = _tmp14_;
#line 314 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp16_ = gee_collection_get_size ((GeeCollection*) _tmp15_);
#line 314 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp17_ = _tmp16_;
#line 314 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (_tmp17_ == 1, "doc.root.namespaces.size == 1");
#line 314 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp15_);
#line 314 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp12_);
#line 315 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp18_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 315 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp19_ = _tmp18_;
#line 315 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp20_ = _tmp19_;
#line 315 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp21_ = gxml_node_get_namespaces (_tmp20_);
#line 315 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp22_ = _tmp21_;
#line 315 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 315 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp24_ = gee_list_get (_tmp23_, 0);
#line 315 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp25_ = (GXmlNamespace*) _tmp24_;
#line 315 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp26_ = gxml_namespace_get_prefix (_tmp25_);
#line 315 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp27_ = _tmp26_;
#line 315 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp28_ = _tmp27_;
#line 315 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp28_, "gxml") == 0, "doc.root.namespaces[0].prefix == \"gxml\"");
#line 315 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp28_);
#line 315 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp25_);
#line 315 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp23_);
#line 315 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp20_);
#line 316 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp29_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 316 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp30_ = _tmp29_;
#line 316 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp31_ = _tmp30_;
#line 316 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp32_ = gxml_node_get_namespaces (_tmp31_);
#line 316 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp33_ = _tmp32_;
#line 316 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp34_ = _tmp33_;
#line 316 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp35_ = gee_list_get (_tmp34_, 0);
#line 316 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp36_ = (GXmlNamespace*) _tmp35_;
#line 316 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp37_ = gxml_namespace_get_uri (_tmp36_);
#line 316 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp38_ = _tmp37_;
#line 316 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp39_ = _tmp38_;
#line 316 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp39_, "http://www.gnome.org/GXml") == 0, "doc.root.namespaces[0].uri == \"http://www.gnome.org/GXml\"");
#line 316 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp39_);
#line 316 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp36_);
#line 316 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp34_);
#line 316 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp31_);
#line 317 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp40_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 317 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp41_ = _tmp40_;
#line 317 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp42_ = _tmp41_;
#line 317 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp43_ = gxml_node_get_children_nodes (_tmp42_);
#line 317 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp44_ = _tmp43_;
#line 317 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp45_ = _tmp44_;
#line 317 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (_tmp45_ != NULL, "doc.root.children_nodes != null");
#line 317 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp45_);
#line 317 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp42_);
#line 318 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp46_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 318 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp47_ = _tmp46_;
#line 318 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp48_ = _tmp47_;
#line 318 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp49_ = gxml_node_get_children_nodes (_tmp48_);
#line 318 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp50_ = _tmp49_;
#line 318 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp51_ = _tmp50_;
#line 318 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp52_ = gee_collection_get_size ((GeeCollection*) _tmp51_);
#line 318 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp53_ = _tmp52_;
#line 318 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (_tmp53_ == 1, "doc.root.children_nodes.size == 1");
#line 318 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp51_);
#line 318 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp48_);
#line 319 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp54_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 319 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp55_ = _tmp54_;
#line 319 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp56_ = _tmp55_;
#line 319 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp57_ = gxml_node_get_children_nodes (_tmp56_);
#line 319 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp58_ = _tmp57_;
#line 319 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp59_ = _tmp58_;
#line 319 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp60_ = gee_list_get ((GeeList*) _tmp59_, 0);
#line 319 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp61_ = (GXmlNode*) _tmp60_;
#line 319 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp59_);
#line 319 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp56_);
#line 319 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		c = _tmp61_;
#line 320 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		gxml_node_set_namespace (c, "http://www.gnome.org/GXml2", "gxml2");
#line 321 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp62_ = gxml_node_get_namespaces (c);
#line 321 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp63_ = _tmp62_;
#line 321 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp64_ = _tmp63_;
#line 321 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (_tmp64_ != NULL, "c.namespaces != null");
#line 321 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp64_);
#line 322 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp65_ = gxml_node_get_namespaces (c);
#line 322 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp66_ = _tmp65_;
#line 322 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp67_ = _tmp66_;
#line 322 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp68_ = gee_collection_get_size ((GeeCollection*) _tmp67_);
#line 322 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp69_ = _tmp68_;
#line 322 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (_tmp69_ == 1, "c.namespaces.size == 1");
#line 322 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp67_);
#line 323 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp70_ = gxml_node_get_namespaces (c);
#line 323 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp71_ = _tmp70_;
#line 323 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp72_ = _tmp71_;
#line 323 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp73_ = gee_list_get (_tmp72_, 0);
#line 323 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp74_ = (GXmlNamespace*) _tmp73_;
#line 323 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp75_ = gxml_namespace_get_prefix (_tmp74_);
#line 323 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp76_ = _tmp75_;
#line 323 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp77_ = _tmp76_;
#line 323 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp77_, "gxml2") == 0, "c.namespaces[0].prefix == \"gxml2\"");
#line 323 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp77_);
#line 323 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp74_);
#line 323 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp72_);
#line 324 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp78_ = gxml_node_get_namespaces (c);
#line 324 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp79_ = _tmp78_;
#line 324 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp80_ = _tmp79_;
#line 324 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp81_ = gee_list_get (_tmp80_, 0);
#line 324 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp82_ = (GXmlNamespace*) _tmp81_;
#line 324 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp83_ = gxml_namespace_get_uri (_tmp82_);
#line 324 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp84_ = _tmp83_;
#line 324 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp85_ = _tmp84_;
#line 324 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp85_, "http://www.gnome.org/GXml2") == 0, "c.namespaces[0].uri == \"http://www.gnome.org/GXml2\"");
#line 324 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp85_);
#line 324 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp82_);
#line 324 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp80_);
#line 325 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		gxml_element_set_attr (G_TYPE_CHECK_INSTANCE_TYPE (c, GXML_TYPE_ELEMENT) ? ((GXmlElement*) c) : NULL, "gxml:prop", "val");
#line 326 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp86_ = gxml_element_get_attr (G_TYPE_CHECK_INSTANCE_TYPE (c, GXML_TYPE_ELEMENT) ? ((GXmlElement*) c) : NULL, "gxml:prop");
#line 326 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		p = _tmp86_;
#line 327 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (p == NULL, "p == null");
#line 328 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp87_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 328 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp88_ = _tmp87_;
#line 328 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp89_ = _tmp88_;
#line 328 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp90_ = gxml_node_to_string (_tmp89_);
#line 328 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp91_ = _tmp90_;
#line 328 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp92_ = g_strconcat ("ROOT: ", _tmp91_, NULL);
#line 328 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp93_ = _tmp92_;
#line 328 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_test_message ("%s", _tmp93_);
#line 328 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp93_);
#line 328 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp91_);
#line 328 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp89_);
#line 329 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp94_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 329 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp95_ = _tmp94_;
#line 329 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp96_ = _tmp95_;
#line 329 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp97_ = gxml_node_to_string (_tmp96_);
#line 329 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp98_ = _tmp97_;
#line 329 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp98_, "<root xmlns:gxml=\"http://www.gnome.org/GXml\"><child xmlns:gxml2=\"ht" \
"tp://www.gnome.org/GXml2\"/></root>") == 0, "doc.root.to_string () == \"<root xmlns:gxml=\\\"http://www.gnome.org/GXml\\\"><child xmlns:gxml2=\\\"http://www.gnome.org/GXml2\\\"/></root>\"");
#line 329 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp98_);
#line 329 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp96_);
#line 330 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp99_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 330 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp100_ = _tmp99_;
#line 330 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp101_ = _tmp100_;
#line 330 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp102_ = gxml_node_get_namespaces (_tmp101_);
#line 330 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp103_ = _tmp102_;
#line 330 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp104_ = _tmp103_;
#line 330 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp105_ = gee_list_get (_tmp104_, 0);
#line 330 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp106_ = (GXmlNamespace*) _tmp105_;
#line 330 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp107_ = gxml_namespace_get_uri (_tmp106_);
#line 330 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp108_ = _tmp107_;
#line 330 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp109_ = _tmp108_;
#line 330 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		gxml_element_set_ns_attr (G_TYPE_CHECK_INSTANCE_TYPE (c, GXML_TYPE_ELEMENT) ? ((GXmlElement*) c) : NULL, _tmp109_, "prop", "Ten");
#line 330 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp109_);
#line 330 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp106_);
#line 330 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp104_);
#line 330 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp101_);
#line 331 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp110_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 331 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp111_ = _tmp110_;
#line 331 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp112_ = _tmp111_;
#line 331 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp113_ = gxml_node_to_string (_tmp112_);
#line 331 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp114_ = _tmp113_;
#line 331 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp115_ = g_strconcat ("ROOT: ", _tmp114_, NULL);
#line 331 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp116_ = _tmp115_;
#line 331 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_test_message ("%s", _tmp116_);
#line 331 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp116_);
#line 331 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp114_);
#line 331 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp112_);
#line 332 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp117_ = gxml_node_get_attrs (c);
#line 332 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp118_ = _tmp117_;
#line 332 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp119_ = _tmp118_;
#line 332 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp120_ = gee_map_get_size (_tmp119_);
#line 332 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp121_ = _tmp120_;
#line 332 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (_tmp121_ == 1, "c.attrs.size == 1");
#line 332 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp119_);
#line 333 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp122_ = gxml_node_get_attrs (c);
#line 333 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp123_ = _tmp122_;
#line 333 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp124_ = _tmp123_;
#line 333 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp125_ = gee_map_get (_tmp124_, "prop");
#line 333 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp126_ = (GXmlNode*) _tmp125_;
#line 333 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp124_);
#line 333 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		pt = _tmp126_;
#line 334 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (pt != NULL, "pt != null");
#line 338 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp127_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 338 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp128_ = _tmp127_;
#line 338 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp129_ = _tmp128_;
#line 338 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp130_ = gxml_node_to_string (_tmp129_);
#line 338 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp131_ = _tmp130_;
#line 338 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp131_, "<root xmlns:gxml=\"http://www.gnome.org/GXml\"><child xmlns:gxml2=\"ht" \
"tp://www.gnome.org/GXml2\" gxml:prop=\"Ten\"/></root>") == 0, "doc.root.to_string () == \"<root xmlns:gxml=\\\"http://www.gnome.org/GXml\\\"><child xmlns:gxml2=\\\"http://www.gnome.org/GXml2\\\" gxml:prop=\\\"Ten\\\"/></root>\"");
#line 338 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp131_);
#line 338 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (_tmp129_);
#line 309 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (pt);
#line 309 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (p);
#line 309 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (c);
#line 309 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_object_unref0 (doc);
#line 4266 "GDocumentTest.c"
	}
	goto __finally165;
	__catch165_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp132_ = NULL;
		gchar* _tmp133_ = NULL;
		gchar* _tmp134_ = NULL;
#line 309 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		e = _inner_error_;
#line 309 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_inner_error_ = NULL;
#line 340 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp132_ = e->message;
#line 340 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp133_ = g_strconcat ("ERROR: ", _tmp132_, NULL);
#line 340 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_tmp134_ = _tmp133_;
#line 340 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_message ("GDocumentTest.vala:340: %s", _tmp134_);
#line 340 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_free0 (_tmp134_);
#line 341 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_assert_not_reached ();
#line 309 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		_g_error_free0 (e);
#line 4293 "GDocumentTest.c"
	}
	__finally165:
#line 309 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 309 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 309 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 309 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
		return;
#line 4304 "GDocumentTest.c"
	}
}


static void ___lambda178__gtest_func (void) {
#line 308 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	__lambda178_ ();
#line 4312 "GDocumentTest.c"
}


static void __lambda179_ (void) {
	GXmlGDocument* doc = NULL;
	GXmlGDocument* _tmp0_ = NULL;
	GXmlNode* _tmp1_ = NULL;
	GXmlNode* _tmp2_ = NULL;
	GXmlNode* _tmp3_ = NULL;
#line 345 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	_tmp0_ = gxml_gdocument_new ();
#line 345 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	doc = _tmp0_;
#line 346 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	_tmp1_ = gxml_gnode_get_parent ((GXmlGNode*) doc);
#line 346 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	_tmp2_ = _tmp1_;
#line 346 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	_tmp3_ = _tmp2_;
#line 346 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	_vala_assert (_tmp3_ == NULL, "doc.parent == null");
#line 346 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	_g_object_unref0 (_tmp3_);
#line 344 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	_g_object_unref0 (doc);
#line 4338 "GDocumentTest.c"
}


static void ___lambda179__gtest_func (void) {
#line 344 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	__lambda179_ ();
#line 4345 "GDocumentTest.c"
}


void gdocument_test_add_tests (void) {
#line 29 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	g_test_add_func ("/gxml/gdocument/construct_api", ___lambda158__gtest_func);
#line 41 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	g_test_add_func ("/gxml/gdocument/construct_from_path_error", ___lambda159__gtest_func);
#line 60 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	g_test_add_func ("/gxml/gdocument/construct_from_stream", ___lambda160__gtest_func);
#line 73 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	g_test_add_func ("/gxml/gdocument/gfile/local", ___lambda161__gtest_func);
#line 93 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	g_test_add_func ("/gxml/gdocument/gfile/remote", ___lambda162__gtest_func);
#line 125 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	g_test_add_func ("/gxml/gdocument/construct_from_stream_error", ___lambda163__gtest_func);
#line 137 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	g_test_add_func ("/gxml/gdocument/construct_from_string", ___lambda164__gtest_func);
#line 154 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	g_test_add_func ("/gxml/gdocument/construct_from_string_no_root", ___lambda165__gtest_func);
#line 164 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	g_test_add_func ("/gxml/gdocument/construct_from_string_invalid", ___lambda166__gtest_func);
#line 173 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	g_test_add_func ("/gxml/gdocument/save", ___lambda167__gtest_func);
#line 187 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	g_test_add_func ("/gxml/gdocument/save_error", ___lambda168__gtest_func);
#line 197 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	g_test_add_func ("/gxml/gdocument/create_element", ___lambda169__gtest_func);
#line 209 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	g_test_add_func ("/gxml/gdocument/create_text_node", ___lambda170__gtest_func);
#line 218 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	g_test_add_func ("/gxml/gdocument/create_comment", ___lambda171__gtest_func);
#line 227 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	g_test_add_func ("/gxml/gdocument/create_cdata_section", ___lambda172__gtest_func);
#line 236 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	g_test_add_func ("/gxml/gdocument/create_processing_instruction", ___lambda173__gtest_func);
#line 247 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	g_test_add_func ("/gxml/gdocument/create_attribute", ___lambda174__gtest_func);
#line 264 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	g_test_add_func ("/gxml/gdocument/to_string/basic", ___lambda175__gtest_func);
#line 275 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	g_test_add_func ("/gxml/gdocument/to_string/extended", ___lambda176__gtest_func);
#line 297 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	g_test_add_func ("/gxml/gdocument/libxml_to_string", ___lambda177__gtest_func);
#line 308 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	g_test_add_func ("/gxml/gdocument/namespace", ___lambda178__gtest_func);
#line 344 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	g_test_add_func ("/gxml/gdocument/parent", ___lambda179__gtest_func);
#line 4394 "GDocumentTest.c"
}


GDocumentTest* gdocument_test_construct (GType object_type) {
	GDocumentTest* self = NULL;
#line 27 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	self = (GDocumentTest*) gxml_test_construct (object_type);
#line 27 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	return self;
#line 4404 "GDocumentTest.c"
}


GDocumentTest* gdocument_test_new (void) {
#line 27 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	return gdocument_test_construct (TYPE_GDOCUMENT_TEST);
#line 4411 "GDocumentTest.c"
}


static void gdocument_test_class_init (GDocumentTestClass * klass) {
#line 27 "/home/despinosa/Proyectos/gxml/test/GDocumentTest.vala"
	gdocument_test_parent_class = g_type_class_peek_parent (klass);
#line 4418 "GDocumentTest.c"
}


static void gdocument_test_instance_init (GDocumentTest * self) {
}


GType gdocument_test_get_type (void) {
	static volatile gsize gdocument_test_type_id__volatile = 0;
	if (g_once_init_enter (&gdocument_test_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GDocumentTestClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gdocument_test_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GDocumentTest), 0, (GInstanceInitFunc) gdocument_test_instance_init, NULL };
		GType gdocument_test_type_id;
		gdocument_test_type_id = g_type_register_static (TYPE_GXML_TEST, "GDocumentTest", &g_define_type_info, 0);
		g_once_init_leave (&gdocument_test_type_id__volatile, gdocument_test_type_id);
	}
	return gdocument_test_type_id__volatile;
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}


static gint _vala_array_length (gpointer array) {
	int length;
	length = 0;
	if (array) {
		while (((gpointer*) array)[length]) {
			length++;
		}
	}
	return length;
}



